@@ -13,15 +13,14 @@
     *                                                                       *
     *************************************************************************
 */
+#include "cwbugdetailscontainer.h"
 
-#include <qpushbutton.h>
-#include <qwidgetstack.h>
-#include <qlayout.h>
-#include <qtooltip.h>
+#include <QPushButton>
+#include <QLayout>
+#include <QtCore/QList>
 
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kactivelabel.h>
 #include <kdialog.h>
 
 #include "bugsystem.h"
@@ -31,23 +30,22 @@
 #include "cwbugdetails.h"
 #include "cwloadingwidget.h"
 
-#include "cwbugdetailscontainer.h"
 #include <kstringhandler.h>
 
 using namespace KBugBusterMainWindow;
 
-CWBugDetailsContainer::CWBugDetailsContainer( QWidget *parent , const char * name )
-: CWBugDetailsContainer_Base( parent, name )
+CWBugDetailsContainer::CWBugDetailsContainer( QWidget *parent  )
+: CWBugDetailsContainer_Base( parent )
 {
     // Do some stuff Designer can't do:
-    m_bugCloseBtn->setIconSet( SmallIconSet( "edittrash" ) );
-    m_bugCloseSilentlyBtn->setIconSet( SmallIconSet( "edittrash" ) );
-    m_bugReopenBtn->setIconSet( SmallIconSet( "idea" ) );
-    m_bugReassignBtn->setIconSet( SmallIconSet( "folder_new" ) );
-    m_bugTitleBtn->setIconSet( SmallIconSet( "text_under" ) );
-    m_bugSeverityBtn->setIconSet( SmallIconSet( "edit" ) );
-    m_bugReplyBtn->setIconSet( SmallIconSet( "mail_replyall" ) );
-    m_bugReplyPrivBtn->setIconSet( SmallIconSet( "mail_reply" ) );
+    m_bugCloseBtn->setIcon( KIcon( "user-trash" ) );
+    m_bugCloseSilentlyBtn->setIcon( KIcon( "user-trash" ) );
+    m_bugReopenBtn->setIcon( KIcon( "help-hint" ) );
+    m_bugReassignBtn->setIcon( KIcon( "folder-new" ) );
+    m_bugTitleBtn->setIcon( KIcon( "edit-rename" ) );
+    m_bugSeverityBtn->setIcon( KIcon( "document-properties" ) );
+    m_bugReplyBtn->setIcon( KIcon( "mail-reply-all" ) );
+    m_bugReplyPrivBtn->setIcon( KIcon( "mail-reply-sender" ) );
 
     // The Bugzilla mail interface doesn't support all commands yet.
     m_bugCloseSilentlyBtn->hide();
@@ -59,22 +57,22 @@ CWBugDetailsContainer::CWBugDetailsContainer( QWidget *parent , const char * nam
     m_bugDetails = new CWBugDetails( m_bugStack );
 
     // Fill WidgetStack in Bug Details pane
-    m_bugLoading = new CWLoadingWidget(
-                        i18n( "Click here to select a bug by number" ),
-                        CWLoadingWidget::BottomFrame, m_bugStack );
+    m_bugLoading = new CWLoadingWidget( CWLoadingWidget::BottomFrame,
+                                        m_bugStack );
     connect( m_bugLoading, SIGNAL( clicked() ), SIGNAL( searchBugNumber() ) );
 
-    m_bugStack->addWidget( m_bugDetails, 0 );
-    m_bugStack->addWidget( m_bugLoading,  1 );
-    m_bugStack->raiseWidget( m_bugLoading );
+    m_bugStack->insertWidget( 0,m_bugDetails );
+    m_bugStack->insertWidget( 1,m_bugLoading );
+
+    setNoBug();
 
     QFont f = m_bugLabel->font();
     f.setBold( true );
     m_bugLabel->setFont( f );
 
     // Set fonts and margins
-    CWBugDetailsContainer_BaseLayout->setSpacing( KDialog::spacingHint() );
-    CWBugDetailsContainer_BaseLayout->setMargin( KDialog::marginHint() );
+    //CWBugDetailsContainer_BaseLayout->setSpacing( KDialog::spacingHint() );
+    //CWBugDetailsContainer_BaseLayout->setMargin( KDialog::marginHint() );
 
     connect( m_bugCloseBtn, SIGNAL( clicked() ), SIGNAL( signalCloseBug() ) );
     connect( m_bugCloseSilentlyBtn, SIGNAL( clicked() ), SIGNAL( signalCloseBugSilently() ) );
@@ -107,7 +105,7 @@ void CWBugDetailsContainer::setBug( const Bug &bug, const BugDetails &details )
     m_bugDetails->setBug( bug, details );
 
     QString labelText;
-     
+
     if ( bug.mergedWith().size() )
     {
        //FIXME: What should the separator be for lists? Don't see anything in KLocale for that
@@ -117,44 +115,44 @@ void CWBugDetailsContainer::setBug( const Bug &bug, const BugDetails &details )
        {
             list += QString::number(*i)+", ";
        }
-       
+
        list.truncate( list.length()-2 ); //Strip off the last ", "
-                     
-       labelText  = i18n("bug #number [Merged with: a list of bugs] (severity): title","Bug #%1 [Merged with: %2] (%3): %4")
-                             .arg( bug.number() )
-                             .arg( list )
-                             .arg( bug.severityAsString() )
-                             .arg( bug.title() );
-    
+
+       labelText  = i18nc("bug #number [Merged with: a list of bugs] (severity): title","Bug #%1 [Merged with: %2] (%3): %4",
+                               bug.number() ,
+                               list ,
+                               bug.severityAsString() ,
+                               bug.title() );
+
     }
     else
     {
-       labelText  = i18n("bug #number (severity): title","Bug #%1 (%2): %3")
-                             .arg( bug.number() ).arg( bug.severityAsString() )
-                             .arg( bug.title() );
+       labelText  = i18nc("bug #number (severity): title","Bug #%1 (%2): %3",
+                               bug.number(), bug.severityAsString() ,
+                               bug.title() );
     }
 
-    m_bugLabel->setText( KStringHandler::tagURLs( labelText ) );
+    m_bugLabel->setText( KStringHandler::tagUrls( labelText ) );
 
     showCommands( bug );
 
     enableButtons( bug );
 
-    m_bugStack->raiseWidget( 0 );
+    m_bugStack->setCurrentIndex( 0 );
     emit resetProgressBar();
 }
 
 void CWBugDetailsContainer::showCommands( const Bug& bug )
 {
-    QPtrList<BugCommand> commands = BugSystem::self()->server()->queryCommands( bug );
+    QList<BugCommand*> commands = BugSystem::self()->server()->queryCommands( bug );
     if ( !commands.isEmpty() ) {
         QString cmdDetails;
-        QString cmdText = i18n("Pending commands:")+" ";
+        QString cmdText = i18n("Pending commands:")+' ';
         bool first = true;
-        QPtrListIterator<BugCommand> cmdIt( commands );
-        for( ; cmdIt.current(); ++cmdIt )
+        QListIterator<BugCommand*> cmdIt( commands );
+        while( cmdIt.hasNext() )
         {
-            BugCommand *cmd = cmdIt.current();
+            BugCommand *cmd = cmdIt.next();
             if (!first)
                 cmdText += "  |  "; // separator in case of multiple commands
             first = false;
@@ -166,9 +164,9 @@ void CWBugDetailsContainer::showCommands( const Bug& bug )
         // Set summary as text label, details into tooltip
         m_cmdLabel->setText( cmdText );
         if ( !cmdDetails.isEmpty() ) {
-            QToolTip::add( m_cmdLabel, cmdDetails );
+            m_cmdLabel->setToolTip( cmdDetails );
         } else {
-            QToolTip::remove( m_cmdLabel );
+            m_cmdLabel->setToolTip("");
         }
         m_cmdLabel->show();
     } else {
@@ -195,14 +193,25 @@ void CWBugDetailsContainer::commandQueued( BugCommand *cmd )
         showCommands( m_bug );
 }
 
+void CWBugDetailsContainer::setNoBug()
+{
+    m_bugLabel->setText( i18n("Bug Title") );
+
+    m_bug = Bug();
+    showCommands( m_bug );
+
+    m_bugLoading->setText( i18n( "Click here to select a bug by number" ) );
+    m_bugStack->setCurrentIndex( 1 );
+}
+
 void CWBugDetailsContainer::setLoading( const Bug &bug )
 {
     m_bug = bug;
     showCommands( bug );
 
-    m_bugLoading->setText(i18n( "Retrieving Details for Bug %1\n\n(%2)" )
-                          .arg( bug.number() ).arg( bug.title() ) );
-    m_bugStack->raiseWidget( 1 );
+    m_bugLoading->setText(i18n( "Retrieving Details for Bug %1\n\n(%2)" ,
+                            bug.number(), bug.title() ) );
+    m_bugStack->setCurrentIndex( 1 );
 }
 
 void CWBugDetailsContainer::setCacheMiss( const Bug &bug )
@@ -212,14 +221,14 @@ void CWBugDetailsContainer::setCacheMiss( const Bug &bug )
 
     QString msg;
     if( BugSystem::self()->disconnected() )
-        msg = i18n( "Bug #%1 (%2) is not available offline." ).
-              arg( bug.number() ).arg( bug.title() );
+        msg = i18n( "Bug #%1 (%2) is not available offline." , 
+               bug.number(), bug.title() );
     else
         msg = i18n( "Retrieving details for bug #%1\n"
-                    "(%2)" ).
-              arg( bug.number() ).arg( bug.title() );
+                    "(%2)" , 
+               bug.number(), bug.title() );
     m_bugLoading->setText( msg );
-    m_bugStack->raiseWidget( 1 );
+    m_bugStack->setCurrentIndex( 1 );
 }
 
 
