@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
@@ -23,35 +23,35 @@
 #ifndef INSTRVIEW_H
 #define INSTRVIEW_H
 
-#include <qlistview.h>
+#include <q3listview.h>
 #include "traceitemview.h"
 
 class InstrItem;
 
-class InstrView : public QListView, public TraceItemView
+class InstrView : public Q3ListView, public TraceItemView
 {
   friend class InstrItem;
 
   Q_OBJECT
 
 public:
-  InstrView(TraceItemView* parentView,
-            QWidget* parent = 0, const char* name = 0);
+  explicit InstrView(TraceItemView* parentView,
+		     QWidget* parent = 0, const char* name = 0);
 
   virtual QWidget* widget() { return this; }
   QString whatsThis() const;
 
-  void readViewConfig(KConfig*, QString prefix, QString postfix, bool);
-  void saveViewConfig(KConfig*, QString prefix, QString postfix, bool);
+  void readViewConfig(KConfig*, const QString& prefix, const QString& postfix, bool);
+  void saveViewConfig(KConfig*, const QString& prefix, const QString& postfix, bool);
 
 protected:
   int arrowLevels() { return _arrowLevels; }
   void paintEmptyArea( QPainter *, const QRect & );
 
 private slots:
-  void context(QListViewItem*, const QPoint &, int);
-  void selectedSlot(QListViewItem *);
-  void activatedSlot(QListViewItem *);
+  void context(Q3ListViewItem*, const QPoint &, int);
+  void selectedSlot(Q3ListViewItem *);
+  void activatedSlot(Q3ListViewItem *);
 
 private:
   TraceItem* canShow(TraceItem*);
@@ -69,7 +69,7 @@ private:
   // arrows
   int _arrowLevels;
   // temporary needed on creation...
-  QMemArray<TraceInstrJump*> _jump;
+  QVector<TraceInstrJump*> _jump;
   TraceInstrJumpList _lowList, _highList;
 
   // remember width of hex code column if hidden
