@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _KIO_SVN_HELPER_H_
@@ -22,8 +22,30 @@
 
 #include <kapplication.h>
 #include <kio/job.h>
-#include <kwinmodule.h>
+#include <kwindowsystem.h>
 #include <qstringlist.h>
+#include "ui_subversioncheckout.h"
+#include "ui_subversionswitch.h"
+#include "ui_subversiondiff.h"
+
+class SubversionCheckout : public QDialog, public Ui::SubversionCheckout
+{
+public:
+  SubversionCheckout( QWidget *parent = 0);
+};
+
+class SubversionSwitch : public QDialog, public Ui::SubversionSwitch
+{
+public:
+  SubversionSwitch( QWidget *parent = 0 );
+};
+
+class Subversion_Diff : public QDialog, public Ui::Subversion_Diff
+{
+public:
+  Subversion_Diff( QWidget *parent = 0 );
+};
+
 
 class SvnHelper:public KApplication {
 	Q_OBJECT
@@ -32,7 +54,7 @@ public:
 	SvnHelper();
 private slots:
 	void finished();
-	void slotResult( KIO::Job *);
+	void slotResult( KJob *);
 private:
 	WId m_id;
 	QStringList diffresult; //for diff commands ;)
