@@ -1,11 +1,10 @@
 /***************************************************************************
-                                KompareNavTreePart.cpp  -  description
-                                -------------------
+                                KompareNavTreePart.cpp
+                                ----------------------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001-2004 Otto Bruggeman
-                                  (C) 2001-2003 John Firebaugh
-        email                   : otto.bruggeman@home.nl
-                                  jfirebaugh@kde.org
+        Copyright 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
+        Copyright 2007      Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
 
 /***************************************************************************
@@ -17,20 +16,21 @@
 **
 ***************************************************************************/
 
+#include "komparenavtreepart.h"
+
 #include <kdebug.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmimetype.h>
-#include <klistview.h>
+#include <k3listview.h>
 #include <kaboutdata.h>
+#include <kcomponentdata.h>
 
 #include "difference.h"
 #include "diffmodel.h"
 #include "diffmodellist.h"
 #include "komparemodellist.h"
 
-#include "komparenavtreepart.h"
-
 #define COL_SOURCE        0
 #define COL_DESTINATION   1
 #define COL_DIFFERENCE    2
@@ -38,7 +38,7 @@
 using namespace Diff2;
 
 KompareNavTreePart::KompareNavTreePart( QWidget* parent, const char* name )
-	: KParts::ReadOnlyPart( parent, name ),
+	: KParts::ReadOnlyPart( parent ),
 	m_splitter( 0 ),
 	m_modelList( 0 ),
 	m_srcDirTree( 0 ),
@@ -53,28 +53,29 @@ KompareNavTreePart::KompareNavTreePart( QWidget* parent, const char* name )
 	m_destination( "" ),
 	m_info( 0 )
 {
+	setObjectName( name );
 	m_splitter = new QSplitter( Qt::Horizontal );
 
 	setWidget( m_splitter );
 
-	m_srcDirTree = new KListView( m_splitter );
+	m_srcDirTree = new K3ListView( m_splitter );
 	m_srcDirTree->addColumn( i18n("Source Folder") );
 	m_srcDirTree->setRootIsDecorated( false );
 	m_srcDirTree->setSorting( 0, true );
 
-	m_destDirTree = new KListView( m_splitter );
+	m_destDirTree = new K3ListView( m_splitter );
 	m_destDirTree->addColumn( i18n("Destination Folder") );
 	m_destDirTree->setRootIsDecorated( false );
 	m_destDirTree->setSorting( 0, true );
 
-	m_fileList = new KListView( m_splitter );
+	m_fileList = new K3ListView( m_splitter );
 	m_fileList->addColumn( i18n("Source File") );
 	m_fileList->addColumn( i18n("Destination File") );
 	m_fileList->setAllColumnsShowFocus( true );
 	m_fileList->setRootIsDecorated( false );
 	m_fileList->setSorting( 0, true );
 
-	m_changesList = new KListView( m_splitter );
+	m_changesList = new K3ListView( m_splitter );
 	m_changesList->addColumn( i18n("Source Line") );
 	m_changesList->addColumn( i18n("Destination Line") );
 	m_changesList->addColumn( i18n("Difference") );
@@ -82,14 +83,14 @@ KompareNavTreePart::KompareNavTreePart( QWidget* parent, const char* name )
 	m_changesList->setRootIsDecorated( false );
 	m_changesList->setSorting( 0, true );
 
-	connect( m_srcDirTree, SIGNAL(selectionChanged( QListViewItem* )),
-	         this, SLOT(slotSrcDirTreeSelectionChanged( QListViewItem* )) );
-	connect( m_destDirTree, SIGNAL(selectionChanged( QListViewItem* )),
-	         this, SLOT(slotDestDirTreeSelectionChanged( QListViewItem* )) );
-	connect( m_fileList, SIGNAL(selectionChanged( QListViewItem* )),
-	         this, SLOT(slotFileListSelectionChanged( QListViewItem* )) );
-	connect( m_changesList, SIGNAL(selectionChanged( QListViewItem* )),
-	         this, SLOT(slotChangesListSelectionChanged( QListViewItem* )) );
+	connect( m_srcDirTree, SIGNAL(selectionChanged( Q3ListViewItem* )),
+	         this, SLOT(slotSrcDirTreeSelectionChanged( Q3ListViewItem* )) );
+	connect( m_destDirTree, SIGNAL(selectionChanged( Q3ListViewItem* )),
+	         this, SLOT(slotDestDirTreeSelectionChanged( Q3ListViewItem* )) );
+	connect( m_fileList, SIGNAL(selectionChanged( Q3ListViewItem* )),
+	         this, SLOT(slotFileListSelectionChanged( Q3ListViewItem* )) );
+	connect( m_changesList, SIGNAL(selectionChanged( Q3ListViewItem* )),
+	         this, SLOT(slotChangesListSelectionChanged( Q3ListViewItem* )) );
 }
 
 KompareNavTreePart::~KompareNavTreePart()
@@ -103,7 +104,7 @@ void KompareNavTreePart::slotKompareInfo( struct Kompare::Info* info )
 
 void KompareNavTreePart::slotModelsChanged( const DiffModelList* modelList )
 {
-	kdDebug(8105) << "Models (" << modelList << ") have changed... scanning the models... " << endl;
+	kDebug(8105) << "Models (" << modelList << ") have changed... scanning the models... " << endl;
 
 	if ( modelList )
 	{
@@ -126,17 +127,17 @@ void KompareNavTreePart::slotModelsChanged( const DiffModelList* modelList )
 
 void KompareNavTreePart::buildTreeInMemory()
 {
-	kdDebug(8105) << "BuildTreeInMemory called" << endl;
+	kDebug(8105) << "BuildTreeInMemory called" << endl;
 
 	if ( m_modelList->count() == 0 )
 	{
-		kdDebug() << "No models... weird shit..." << endl;
+		kDebug() << "No models... weird shit..." << endl;
 		return; // avoids a crash on clear()
 	}
 
 	if ( m_info == 0 )
 	{
-		kdDebug() << "No Info... weird shit..." << endl;
+		kDebug() << "No Info... weird shit..." << endl;
 		return;
 	}
 
@@ -159,20 +160,20 @@ void KompareNavTreePart::buildTreeInMemory()
 		break;
 	case Kompare::ComparingDirs:
 		srcBase = m_info->localSource;
-		if ( !srcBase.endsWith( "/" ) )
-			srcBase += "/";
+		if ( !srcBase.endsWith( '/' ) )
+			srcBase += '/';
 		destBase = m_info->localDestination;
-		if ( !destBase.endsWith( "/" ) )
-			destBase += "/";
+		if ( !destBase.endsWith( '/' ) )
+			destBase += '/';
 		break;
 	case Kompare::BlendingFile:
 	case Kompare::BlendingDir:
 	default:
-		kdDebug(8105) << "Oops needs to implement this..." << endl;
+		kDebug(8105) << "Oops needs to implement this..." << endl;
 	}
 
-//	kdDebug(8105) << "srcBase  = " << srcBase << endl;
-//	kdDebug(8105) << "destBase = " << destBase << endl;
+//	kDebug(8105) << "srcBase  = " << srcBase << endl;
+//	kDebug(8105) << "destBase = " << destBase << endl;
 
 	m_srcRootItem  = new KDirLVI( m_srcDirTree, srcBase );
 	m_destRootItem = new KDirLVI( m_destDirTree, destBase );
@@ -190,8 +191,8 @@ void KompareNavTreePart::buildTreeInMemory()
 		srcPath  = model->sourcePath();
 		destPath = model->destinationPath();
 
-		kdDebug(8105) << "srcPath  = " << srcPath  << endl;
-		kdDebug(8105) << "destPath = " << destPath << endl;
+		kDebug(8105) << "srcPath  = " << srcPath  << endl;
+		kDebug(8105) << "destPath = " << destPath << endl;
 		m_srcRootItem->addModel( srcPath, model, &m_modelToSrcDirItemDict );
 		m_destRootItem->addModel( destPath, model, &m_modelToDestDirItemDict );
 	}
@@ -201,7 +202,7 @@ void KompareNavTreePart::buildTreeInMemory()
 void KompareNavTreePart::buildDirectoryTree()
 {
 // FIXME: afaict this can be deleted
-//	kdDebug(8105) << "BuildDirTree called" << endl;
+//	kDebug(8105) << "BuildDirTree called" << endl;
 }
 
 QString KompareNavTreePart::compareFromEndAndReturnSame(
@@ -221,7 +222,7 @@ QString KompareNavTreePart::compareFromEndAndReturnSame(
 			break;
 	}
 
-	if ( srcLen != 0 && destLen != 0 && result.startsWith( "/" ) )
+	if ( srcLen != 0 && destLen != 0 && result.startsWith( '/' ) )
 		result = result.remove( 0, 1 ); // strip leading /, we need it later
 
 	return result;
@@ -229,7 +230,7 @@ QString KompareNavTreePart::compareFromEndAndReturnSame(
 
 void KompareNavTreePart::slotSetSelection( const DiffModel* model, const Difference* diff )
 {
-	kdDebug(8105) << "KompareNavTreePart::slotSetSelection model = " << model << ", diff = " << diff << endl;
+	kDebug(8105) << "KompareNavTreePart::slotSetSelection model = " << model << ", diff = " << diff << endl;
 	if ( model == m_selectedModel )
 	{
 		// model is the same, so no need to update that...
@@ -268,14 +269,14 @@ void KompareNavTreePart::setSelectedDir( const DiffModel* model )
 {
 	KDirLVI* currentDir;
 	currentDir = m_modelToSrcDirItemDict[ (void*)model ];
-	kdDebug(8105) << "Manually setting selection in srcdirtree with currentDir = " << currentDir << endl;
+	kDebug(8105) << "Manually setting selection in srcdirtree with currentDir = " << currentDir << endl;
 	m_srcDirTree->blockSignals( true );
 	m_srcDirTree->setSelected( currentDir, true );
 	m_srcDirTree->ensureItemVisible( currentDir );
 	m_srcDirTree->blockSignals( false );
 
 	currentDir = m_modelToDestDirItemDict[ (void*)model ];
-	kdDebug(8105) << "Manually setting selection in destdirtree with currentDir = " << currentDir << endl;
+	kDebug(8105) << "Manually setting selection in destdirtree with currentDir = " << currentDir << endl;
 	m_destDirTree->blockSignals( true );
 	m_destDirTree->setSelected( currentDir, true );
 	m_destDirTree->ensureItemVisible( currentDir );
@@ -290,7 +291,7 @@ void KompareNavTreePart::setSelectedFile( const DiffModel* model )
 {
 	KFileLVI* currentFile;
 	currentFile = m_modelToFileItemDict[ (void*)model ];
-	kdDebug(8105) << "Manually setting selection in filelist" << endl;
+	kDebug(8105) << "Manually setting selection in filelist" << endl;
 	m_fileList->blockSignals( true );
 	m_fileList->setSelected( currentFile, true );
 	m_fileList->ensureItemVisible( currentFile );
@@ -305,7 +306,7 @@ void KompareNavTreePart::setSelectedDifference( const Difference* diff )
 {
 	KChangeLVI* currentDiff;
 	currentDiff = m_diffToChangeItemDict[ (void*)diff ];
-	kdDebug(8105) << "Manually setting selection in changeslist to " << currentDiff << endl;
+	kDebug(8105) << "Manually setting selection in changeslist to " << currentDiff << endl;
 	m_changesList->blockSignals( true );
 	m_changesList->setSelected( currentDiff, true );
 	m_changesList->ensureItemVisible( currentDiff );
@@ -314,18 +315,18 @@ void KompareNavTreePart::setSelectedDifference( const Difference* diff )
 
 void KompareNavTreePart::slotSetSelection( const Difference* diff )
 {
-//	kdDebug(8105) << "Scotty i need more power !!" << endl;
+//	kDebug(8105) << "Scotty i need more power !!" << endl;
 	if ( m_selectedDifference != diff )
 	{
-//		kdDebug(8105) << "But sir, i am giving you all she's got" << endl;
+//		kDebug(8105) << "But sir, i am giving you all she's got" << endl;
 		m_selectedDifference = diff;
 		setSelectedDifference( diff );
 	}
 }
 
-void KompareNavTreePart::slotSrcDirTreeSelectionChanged( QListViewItem* item )
+void KompareNavTreePart::slotSrcDirTreeSelectionChanged( Q3ListViewItem* item )
 {
-	kdDebug(8105) << "Sent by the sourceDirectoryTree with item = " << item << endl;
+	kDebug(8105) << "Sent by the sourceDirectoryTree with item = " << item << endl;
 	m_srcDirTree->ensureItemVisible( item );
 	KDirLVI* dir = static_cast<KDirLVI*>(item);
 	// order the dest tree view to set its selected item to the same as here
@@ -341,9 +342,9 @@ void KompareNavTreePart::slotSrcDirTreeSelectionChanged( QListViewItem* item )
 	dir->fillFileList( m_fileList, &m_modelToFileItemDict );
 }
 
-void KompareNavTreePart::slotDestDirTreeSelectionChanged( QListViewItem* item )
+void KompareNavTreePart::slotDestDirTreeSelectionChanged( Q3ListViewItem* item )
 {
-	kdDebug(8105) << "Sent by the destinationDirectoryTree with item = " << item << endl;
+	kDebug(8105) << "Sent by the destinationDirectoryTree with item = " << item << endl;
 	m_destDirTree->ensureItemVisible( item );
 	KDirLVI* dir = static_cast<KDirLVI*>(item);
 	// order the src tree view to set its selected item to the same as here
@@ -359,9 +360,9 @@ void KompareNavTreePart::slotDestDirTreeSelectionChanged( QListViewItem* item )
 	dir->fillFileList( m_fileList, &m_modelToFileItemDict );
 }
 
-void KompareNavTreePart::slotFileListSelectionChanged( QListViewItem* item )
+void KompareNavTreePart::slotFileListSelectionChanged( Q3ListViewItem* item )
 {
-	kdDebug(8105) << "Sent by the fileList with item = " << item << endl;
+	kDebug(8105) << "Sent by the fileList with item = " << item << endl;
 
 	KFileLVI* file = static_cast<KFileLVI*>(item);
 	m_selectedModel = file->model();
@@ -378,9 +379,9 @@ void KompareNavTreePart::slotFileListSelectionChanged( QListViewItem* item )
 	emit selectionChanged( m_selectedModel, m_selectedDifference );
 }
 
-void KompareNavTreePart::slotChangesListSelectionChanged( QListViewItem* item )
+void KompareNavTreePart::slotChangesListSelectionChanged( Q3ListViewItem* item )
 {
-	kdDebug(8105) << "Sent by the changesList" << endl;
+	kDebug(8105) << "Sent by the changesList" << endl;
 
 	KChangeLVI* change = static_cast<KChangeLVI*>(item);
 	m_selectedDifference = change->difference();
@@ -397,9 +398,9 @@ void KompareNavTreePart::slotApplyDifference( bool /*apply*/ )
 
 void KompareNavTreePart::slotApplyAllDifferences( bool /*apply*/ )
 {
-	QPtrDictIterator<KChangeLVI> it( m_diffToChangeItemDict );
+	Q3PtrDictIterator<KChangeLVI> it( m_diffToChangeItemDict );
 
-	kdDebug() << "m_diffToChangeItemDict.count() = " << m_diffToChangeItemDict.count() << endl;
+	kDebug(8105) << "m_diffToChangeItemDict.count() = " << m_diffToChangeItemDict.count() << endl;
 
 	for ( ; it.current(); ++it )
 	{
@@ -423,37 +424,37 @@ void KChangeLVI::setDifferenceText()
 		// Shouldn't this simply be diff->sourceLineCount() ?
 		// because you change the _number of lines_ lines in source, not in dest
 		if( m_difference->applied() )
-			text = i18n( "Applied: Changes made to %n line undone", "Applied: Changes made to  %n lines undone",
+			text = i18np( "Applied: Changes made to %1 line undone", "Applied: Changes made to  %1 lines undone",
 			             m_difference->sourceLineCount() );
 		else
-			text = i18n( "Changed %n line", "Changed %n lines",
+			text = i18np( "Changed %1 line", "Changed %1 lines",
 			             m_difference->sourceLineCount() );
 		break;
 	case Difference::Insert:
 		if( m_difference->applied() )
-			text = i18n( "Applied: Insertion of %n line undone", "Applied: Insertion of %n lines undone",
+			text = i18np( "Applied: Insertion of %1 line undone", "Applied: Insertion of %1 lines undone",
 			             m_difference->destinationLineCount() );
 		else
-			text = i18n( "Inserted %n line", "Inserted %n lines",
+			text = i18np( "Inserted %1 line", "Inserted %1 lines",
 			             m_difference->destinationLineCount() );
 		break;
 	case Difference::Delete:
 		if( m_difference->applied() )
-			text = i18n( "Applied: Deletion of %n line undone", "Applied: Deletion of %n lines undone",
+			text = i18np( "Applied: Deletion of %1 line undone", "Applied: Deletion of %1 lines undone",
 			             m_difference->sourceLineCount() );
 		else
-			text = i18n( "Deleted %n line", "Deleted %n lines",
+			text = i18np( "Deleted %1 line", "Deleted %1 lines",
 			             m_difference->sourceLineCount() );
 		break;
 	default:
-		kdDebug(8105) << "Unknown or Unchanged enum value when checking for diff->type() in KChangeLVI's constructor" << endl;
+		kDebug(8105) << "Unknown or Unchanged enum value when checking for diff->type() in KChangeLVI's constructor" << endl;
 		text = "";
 	}
 
 	setText( 2, text );
 }
 
-KChangeLVI::KChangeLVI( KListView* parent, Difference* diff ) : KListViewItem( parent )
+KChangeLVI::KChangeLVI( K3ListView* parent, Difference* diff ) : K3ListViewItem( parent )
 {
 	m_difference = diff;
 
@@ -463,7 +464,7 @@ KChangeLVI::KChangeLVI( KListView* parent, Difference* diff ) : KListViewItem( p
 	setDifferenceText();
 }
 
-int KChangeLVI::compare( QListViewItem* item, int column, bool ascending ) const
+int KChangeLVI::compare( Q3ListViewItem* item, int column, bool ascending ) const
 {
 	if ( ascending )
 	{
@@ -487,18 +488,96 @@ KChangeLVI::~KChangeLVI()
 {
 }
 
-KFileLVI::KFileLVI( KListView* parent, DiffModel* model ) : KListViewItem( parent )
+KFileLVI::KFileLVI( K3ListView* parent, DiffModel* model ) : K3ListViewItem( parent )
 {
 	m_model = model;
 
-	setText( 0, model->sourceFile() );
-	setText( 1, model->destinationFile() );
-	setPixmap( 0, SmallIcon( "txt" ) );
-	setPixmap( 1, SmallIcon( "txt" ) );
+	QString src = model->sourceFile();
+	QString dst = model->destinationFile();
+
+	setText( 0, src );
+	setText( 1, dst );
+	setPixmap( 0, SmallIcon( getIcon( src ) ) );
+	setPixmap( 1, SmallIcon( getIcon( dst ) ) );
 	setSelectable( true );
 }
 
-void KFileLVI::fillChangesList( KListView* changesList, QPtrDict<KChangeLVI>* diffToChangeItemDict )
+bool KFileLVI::hasExtension(const QString& extensions, const QString& fileName)
+{
+    QStringList extList = extensions.split(' ');
+	foreach (const QString &ext, extList) {
+		if ( fileName.endsWith(ext, Qt::CaseInsensitive) ) {
+			return true;
+		}
+	}
+	return false;
+}
+
+const QString KFileLVI::getIcon(const QString& fileName)
+{
+	// C++, C
+	if ( hasExtension( ".h .hpp", fileName ) ) {
+		return "text-x-c++hdr";
+	}
+	if ( hasExtension( ".cpp", fileName ) ) {
+		return "text-x-c++src";
+	}
+	if ( hasExtension( ".c", fileName ) ) {
+		return "text-x-csrc";
+	}
+	// Python
+	if ( hasExtension( ".py .pyw", fileName ) ) {
+		return "text-x-python";
+	}
+	// C#
+	if ( hasExtension( ".cs", fileName ) ) {
+		return "text-x-csharp";
+	}
+	// Objective-C
+	if ( hasExtension( ".m", fileName ) ) {
+		return "text-x-objcsrc";
+	}
+	// Java
+	if ( hasExtension( ".java", fileName ) ) {
+		return "text-x-java";
+	}
+	// Script
+	if ( hasExtension( ".sh", fileName ) ) {
+		return "text-x-script";
+	}
+	// Makefile
+	if ( hasExtension( ".cmake Makefile", fileName ) ) {
+		return "text-x-makefile";
+	}
+	// Ada
+	if ( hasExtension( ".ada .ads .adb", fileName ) ) {
+		return "text-x-adasrc";
+	}
+	// Pascal
+	if ( hasExtension( ".pas", fileName ) ) {
+		return "text-x-pascal";
+	}
+	// Patch
+	if ( hasExtension( ".diff", fileName ) ) {
+		return "text-x-patch";
+	}
+	// Tcl
+	if ( hasExtension( ".tcl", fileName ) ) {
+		return "text-x-tcl";
+	}
+	// Text
+	if ( hasExtension( ".txt", fileName ) ) {
+		return "text-plain";
+	}
+	// Xml
+	if ( hasExtension( ".xml", fileName ) ) {
+		return "text-xml";
+	}
+	// unknown or no file extension
+	return "text-plain";
+}
+
+void KFileLVI::fillChangesList( K3ListView* changesList, Q3PtrDict<KChangeLVI>* diffToChangeItemDict )
 {
 	changesList->clear();
 	diffToChangeItemDict->clear();
@@ -519,9 +598,9 @@ KFileLVI::~KFileLVI()
 {
 }
 
-KDirLVI::KDirLVI( KListView* parent, QString& dir ) : KListViewItem( parent )
+KDirLVI::KDirLVI( K3ListView* parent, QString& dir ) : K3ListViewItem( parent )
 {
-//	kdDebug(8105) << "KDirLVI (KListView) constructor called with dir = " << dir << endl;
+//	kDebug(8105) << "KDirLVI (K3ListView) constructor called with dir = " << dir << endl;
 	m_rootItem = true;
 	m_dirName = dir;
 	setPixmap( 0, SmallIcon( "folder" ) );
@@ -533,9 +612,9 @@ KDirLVI::KDirLVI( KListView* parent, QString& dir ) : KListViewItem( parent )
 		setText( 0, m_dirName );
 }
 
-KDirLVI::KDirLVI( KDirLVI* parent, QString& dir ) : KListViewItem( parent )
+KDirLVI::KDirLVI( KDirLVI* parent, QString& dir ) : K3ListViewItem( parent )
 {
-//	kdDebug(8105) << "KDirLVI (KDirLVI) constructor called with dir = " << dir << endl;
+//	kDebug(8105) << "KDirLVI (KDirLVI) constructor called with dir = " << dir << endl;
 	m_rootItem = false;
 	m_dirName = dir;
 	setPixmap( 0, SmallIcon( "folder" ) );
@@ -545,9 +624,9 @@ KDirLVI::KDirLVI( KDirLVI* parent, QString& dir ) : KListViewItem( parent )
 }
 
 // addModel always removes it own path from the beginning
-void KDirLVI::addModel( QString& path, DiffModel* model, QPtrDict<KDirLVI>* modelToDirItemDict )
+void KDirLVI::addModel( QString& path, DiffModel* model, Q3PtrDict<KDirLVI>* modelToDirItemDict )
 {
-//	kdDebug(8105) << "KDirLVI::addModel called with path = " << path << " from KDirLVI with m_dirName = " << m_dirName << endl;
+//	kDebug(8105) << "KDirLVI::addModel called with path = " << path << " from KDirLVI with m_dirName = " << m_dirName << endl;
 
 	if ( !m_dirName.isEmpty() )
 	{
@@ -555,7 +634,7 @@ void KDirLVI::addModel( QString& path, DiffModel* model, QPtrDict<KDirLVI>* mode
 			path = path.replace( path.find( m_dirName ), m_dirName.length(), "" );
 	}
 
-//	kdDebug(8105) << "Path after removal of own dir (\"" << m_dirName << "\") = " << path << endl;
+//	kDebug(8105) << "Path after removal of own dir (\"" << m_dirName << "\") = " << path << endl;
 
 	if ( path.isEmpty() ) {
 		m_modelList.append( model );
@@ -570,7 +649,7 @@ void KDirLVI::addModel( QString& path, DiffModel* model, QPtrDict<KDirLVI>* mode
 	if ( !child )
 	{
 		// does not exist yet so make it
-//		kdDebug(8105) << "KDirLVI::addModel creating new KDirLVI because not found" << endl;
+//		kDebug(8105) << "KDirLVI::addModel creating new KDirLVI because not found" << endl;
 		child = new KDirLVI( this, dir );
 	}
 
@@ -579,7 +658,7 @@ void KDirLVI::addModel( QString& path, DiffModel* model, QPtrDict<KDirLVI>* mode
 
 KDirLVI* KDirLVI::findChild( QString dir )
 {
-//	kdDebug(8105) << "KDirLVI::findChild called with dir = " << dir << endl;
+//	kDebug(8105) << "KDirLVI::findChild called with dir = " << dir << endl;
 	KDirLVI* child;
 	if ( ( child = static_cast<KDirLVI*>(this->firstChild()) ) != 0L )
 	{ // has children, check if dir already exists, if so addModel
@@ -592,7 +671,7 @@ KDirLVI* KDirLVI::findChild( QString dir )
 	return 0L;
 }
 
-void KDirLVI::fillFileList( KListView* fileList, QPtrDict<KFileLVI>* modelToFileItemDict )
+void KDirLVI::fillFileList( K3ListView* fileList, Q3PtrDict<KFileLVI>* modelToFileItemDict )
 {
 	fileList->clear();
 
@@ -610,11 +689,11 @@ void KDirLVI::fillFileList( KListView* fileList, QPtrDict<KFileLVI>* modelToFile
 QString KDirLVI::fullPath( QString& path )
 {
 //	if ( !path.isEmpty() )
-//		kdDebug(8105) << "KDirLVI::fullPath called with path = " << path << endl;
+//		kDebug(8105) << "KDirLVI::fullPath called with path = " << path << endl;
 //	else
-//		kdDebug(8105) << "KDirLVI::fullPath called with empty path..." << endl;
+//		kDebug(8105) << "KDirLVI::fullPath called with empty path..." << endl;
 
-	if ( m_rootItem ) // dont bother adding rootItem's dir...
+	if ( m_rootItem ) // don't bother adding rootItem's dir...
 		return path;
 
 	path = path.prepend( m_dirName );
@@ -630,7 +709,7 @@ QString KDirLVI::fullPath( QString& path )
 
 KDirLVI* KDirLVI::setSelected( QString dir )
 {
-//	kdDebug(8105) << "KDirLVI::setSelected called with dir = " << dir << endl;
+//	kDebug(8105) << "KDirLVI::setSelected called with dir = " << dir << endl;
 
 	// root item's dirName is never taken into account... remember that
 	if ( !m_rootItem )
@@ -659,7 +738,7 @@ KDirLVI::~KDirLVI()
 }
 
 // part stuff
-KInstance*  KompareNavTreePartFactory::s_instance = 0L;
+KComponentData *KompareNavTreePartFactory::s_instance = 0L;
 KAboutData* KompareNavTreePartFactory::s_about = 0L;
 
 KompareNavTreePartFactory::KompareNavTreePartFactory()
@@ -675,36 +754,31 @@ KompareNavTreePartFactory::~KompareNavTreePartFactory()
 	s_instance = 0L;
 }
 
-KParts::Part* KompareNavTreePartFactory::createPartObject( QWidget* parentWidget, const char* widgetName,
-                                                  QObject* /*parent*/, const char* /*name*/,
+KParts::Part* KompareNavTreePartFactory::createPartObject( QWidget* parentWidget,
+                                                  QObject* /*parent*/,
                                                   const char* /*classname*/, const QStringList & /*args*/ )
 {
 	// Create an instance of our Part
-	KompareNavTreePart* obj = new KompareNavTreePart( parentWidget, widgetName );
+	KompareNavTreePart* obj = new KompareNavTreePart( parentWidget, 0 );
 
-	KGlobal::locale()->insertCatalogue("kompare");
+	KGlobal::locale()->insertCatalog("kompare");
 
 	return obj;
 }
 
-KInstance* KompareNavTreePartFactory::instance()
+const KComponentData &KompareNavTreePartFactory::componentData()
 {
 	if( !s_instance )
 	{
-		s_about = new KAboutData("komparenavtreepart", I18N_NOOP("KompareNavTreePart"), "1.1");
-		s_about->addAuthor("John Firebaugh", "Author", "jfirebaugh@kde.org");
-		s_about->addAuthor("Otto Bruggeman", "Author", "otto.bruggeman@home.nl" );
-		s_instance = new KInstance(s_about);
+		s_about = new KAboutData("komparenavtreepart", 0, ki18n("KompareNavTreePart"), "1.1");
+		s_about->addAuthor(ki18n("John Firebaugh"), ki18n("Author"), "jfirebaugh@kde.org");
+		s_about->addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "otto.bruggeman@home.nl" );
+		s_instance = new KComponentData(s_about);
 	}
-	return s_instance;
+	return *s_instance;
 }
 
-extern "C"
-{
-	KDE_EXPORT void* init_libkomparenavtreepart()
-	{
-		return new KompareNavTreePartFactory;
-	}
-}
+K_EXPORT_COMPONENT_FACTORY( libkomparenavtreepart, KompareNavTreePartFactory )
+K_EXPORT_PLUGIN( KompareNavTreePartFactory )
 
 #include "komparenavtreepart.moc"
