@@ -1,13 +1,12 @@
 /***************************************************************************
-                                prefsbase.h  -  description
-                                -------------------
+                                prefsbase.h
+                                -----------
         begin                   : Sun Mar 4 2001
-        copyright               : (C) 2001 by Otto Bruggeman
-                                  and John Firebaugh
-        email                   : otto.bruggeman@home.nl
-                                  jfirebaugh@kde.org
+        Copyright 2001 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001 John Firebaugh <jfirebaugh@kde.org>
+        Copyright 2007 Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
- 
+
 /***************************************************************************
 **
 **   This program is free software; you can redistribute it and/or modify
@@ -20,19 +19,17 @@
 #ifndef PAGEBASE_H
 #define PAGEBASE_H
 
-#include <qsize.h>
-#include <qwidget.h>
+#include <QtCore/QSize>
 
-#include <kconfig.h>
-#include <ktabctl.h>
+#include <kvbox.h>
 
 #include "kompare.h"
 
-class PageBase : public KTabCtl
+class PageBase : public KVBox
 {
 Q_OBJECT
-public: 
-	PageBase( QWidget* );
+public:
+	PageBase();
 	~PageBase();
 
 public:
