@@ -15,15 +15,19 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <klistviewsearchline.h>
+#include <k3listviewsearchline.h>
 #include <klocale.h>
 
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlistview.h>
+#include <q3listview.h>
 #include <qsplitter.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QKeyEvent>
+#include <QEvent>
 #include <ktabwidget.h>
-#include <qvbox.h>
+#include <kvbox.h>
 
 #include "navview.h"
 #include "propsview.h"
@@ -47,14 +51,16 @@ extern "C"
 Spy::Spy( QWidget *parent, const char *name )
   : QWidget( parent, name )
 {
-  QVBoxLayout *layout = new QVBoxLayout( this, 11, 6 );
+  QVBoxLayout *layout = new QVBoxLayout( this );
+  layout->setSpacing( 6 );
+  layout->setMargin( 11 );
 
   QSplitter *div = new QSplitter( this );
   layout->addWidget( div );
 
-  QVBox *leftPane = new QVBox( div );
+  KVBox *leftPane = new KVBox( div );
 
-  KListViewSearchLine *searchLine = new KListViewSearchLine( leftPane, "search line" );
+  K3ListViewSearchLine *searchLine = new K3ListViewSearchLine( leftPane, "search line" );
   mNavView = new NavView( leftPane, "navigation view" );
   searchLine->setListView( mNavView );
 
