@@ -54,6 +54,9 @@
 #include <kdebug.h>
 #include <kurl.h>
 #include <kstandardshortcut.h>
+#include <kcolorscheme.h>
+
+
 //parent is set on qsplitter insertion
 class LedsWidget:public QWidget
 {
@@ -64,12 +67,14 @@ public:
 //     , _ledUntr(0)
 //     , _ledErr(0)
     {
+        KColorScheme colorScheme(QPalette::Normal);
+
         QHBoxLayout* layout=new QHBoxLayout(this);
         layout->addStretch();
         layout->addWidget(new QLabel(i18nc("@label whether entry is fuzzy","Fuzzy:")));
-        layout->addWidget(ledFuzzy=new KLed(Qt::green,KLed::Off,KLed::Sunken,KLed::Rectangular));
+        layout->addWidget(ledFuzzy=new KLed(colorScheme.foreground(KColorScheme::NeutralText)/*Qt::green*/,KLed::Off,KLed::Sunken,KLed::Rectangular));
         layout->addWidget(new QLabel(i18nc("@label whether entry is fuzzy","Untranslated:")));
-        layout->addWidget(ledUntr=new KLed(Qt::red,KLed::Off,KLed::Sunken,KLed::Rectangular));
+        layout->addWidget(ledUntr=new KLed(colorScheme.foreground(KColorScheme::NegativeText)/*Qt::red*/,KLed::Off,KLed::Sunken,KLed::Rectangular));
         layout->addStretch();
         setMaximumHeight(minimumSizeHint().height());
     }
@@ -137,7 +142,7 @@ KAiderView::KAiderView(QWidget *parent,Catalog* catalog/*,keyEventHandler* kh*/)
     , _tabbar(new KTabBar(this))
     , _leds(0)
     , _currentEntry(-1)
-    , m_approvementState(false)
+    , m_approvementState(true)
 {
     //( new QTreeView(this) )->selectAll();
     _tabbar->hide();
@@ -252,7 +257,10 @@ bool KAiderView::eventFilter(QObject * /*obj*/, QEvent *event)
     }
     else if (!keyEvent->modifiers()&&(keyEvent->key()==Qt::Key_Backspace||keyEvent->key()==Qt::Key_Delete))
     {
-        if (KDE_ISUNLIKELY( !_catalog->isApproved(_currentEntry) ))
+        //only for cases when:
+        //-BkSpace was hit and cursor was atStart
+        //-Del was hit and cursor was atEnd
+        if (KDE_ISUNLIKELY( !_catalog->isApproved(_currentEntry) && !_msgstrEdit->textCursor().hasSelection() ))
             toggleApprovement(true);
         return false;
     }
@@ -561,9 +569,12 @@ void KAiderView::gotoEntry(const DocPosition& pos,int selection/*, bool updateHi
 
     if (pos.offset || selection)
     {
-
         if (pos.part==Msgid)
+        {
             msgEdit=_msgidEdit;
+            t=msgEdit->textCursor();
+            t.movePosition(QTextCursor::Start);
+        }
 
         t.movePosition(QTextCursor::NextCharacter,QTextCursor::MoveAnchor,pos.offset);
         //NOTE this was kinda bug due to on-the-fly msgid wordwrap
@@ -588,7 +599,7 @@ void KAiderView::gotoEntry(const DocPosition& pos,int selection/*, bool updateHi
 //     m_msgstrHighlighter->rehighlight();
 //     connect (_msgstrEdit->document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
 
-    msgEdit->setFocus();
+    _msgstrEdit->setFocus();
 
     setUpdatesEnabled(true);
 }
