@@ -14,7 +14,7 @@
 ;;
 ;; You should have received a copy of the GNU Lesser General Public
 ;; License along with this library; if not, write to the Free Software
-;; Foundation, Inc., 51 Franklin Steet, Fifth Floor, Boston, MA
+;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 ;; 02110-1301  USA
 
 
@@ -35,6 +35,9 @@ This function does not do any hidden buffer changes."
       `(scan-lists ,from ,count ,depth nil t)
     `(c-safe (scan-lists ,from ,count ,depth))))
 
+(if (not (eq kde-include-directory nil))
+    (setq sourcepair-header-path (list "." kde-include-directory "/*")))
+
 ;; returns non-nil if the given file has a using declaration
 ;; with the passed namespace
 (defun kde-file-has-using (namespace)
@@ -48,7 +51,6 @@ This function does not do any hidden buffer changes."
       )
     found)
   )
-
 ;; returns non-nill if the given file has a "namespace SomeNM" declaration
 ;; where SomeNM is passed via the namespace argument
 (defun kde-file-is-in-namespace (namespace)
@@ -63,6 +65,25 @@ This function does not do any hidden buffer changes."
     found)
   )
 
+; Helper function for getting the baseclass of the current class - in a C++ header file
+; Only supports single inheritance
+(defun baseclass-under-point ()
+  (let ((pos (c-safe-scan-lists (point) -1 1)))
+    (save-excursion
+      (goto-char (if pos pos (point-min)))
+      (backward-word 2)			; move back over "public baseclass"
+      (if (looking-at "public\\|protected\\|private[ \t]*")
+	  (progn
+	    (forward-word)
+	    (while (looking-at "[ \t]")
+	      (forward-char 1))
+	    (let ((start (point)))
+	      (forward-word)
+	      (buffer-substring start (point))))
+	nil
+	)))
+    )
+
 ; Helper function for parsing our current position in a C++ header file
 ; returns (namespace (class function)) where (a b) is a cons.
 (defun method-under-point ()
@@ -121,6 +142,10 @@ This function does not do any hidden buffer changes."
       ; now that we moved back enough, go to beginning of line.
       ; (we assume that the return type, function name, and '(' are on the same line)
       (re-search-backward "^[ \t]*")
+      (while (looking-at "[ \t]")
+	(forward-char 1))
+      (when (looking-at "/\\*") ; C-style comment, like /*! \reimp */
+	(re-search-forward "\\*/" nil t))
       (while (looking-at "[ \t]")
 	(forward-char 1))
       (setq function (buffer-substring (point) end))
@@ -205,38 +230,56 @@ This function does not do any hidden buffer changes."
         (function "")
         found
 	)
-    (if (or (string-match "\\.cc$" n)
-            (string-match "\\.cpp$" n)
-            (string-match "\\.C$" n))
+    (if (member (concat "." (file-name-extension n)) sourcepair-source-extensions)
         ; TODO replace fume-function-before-point, needed for emacs,
         ; and for better namespace support.
 	;(progn
 	;  (let ((pos (kde-scan-lists (point) -1 1 nil t))) ; Go up a level
 	;    (goto-char (if pos (+ pos 1) (point-min))))
-        (let ((a (fume-function-before-point)))
-          (and (string-match "^\\(.*\\)::\\(.*\\)$" a)
-               (progn
-                 (setq class (match-string 1 a))
-                 (setq function (match-string 2 a))
-                 (kde-switch-cpp-h)
-                 (goto-char 0)
-		 ; Look for beginning of class ("\\s-+" means whitespace including newlines)
-                 (re-search-forward
-		  (concat "\\(class\\|struct\\|namespace\\)\\s-+"
-			  "\\([A-Z_]+_EXPORT[A-Z_]*\\)?\\s-+"  ; allow for optional EXPORT macro
-			  class "\\b"                          ; the classname - with word separator
-			  "[^;]+{"                             ; the optional inheritance and the '{'
-			  ) nil t)
-                 ;; TODO keep looking, until we find a match that's not inside a comment
-                 (re-search-forward (concat "\\b" (kde-function-regexp-quote function) "[ \t]*(") nil t)))))
+        (let ((a (fume-function-before-point))
+	      (functionregexp ""))
+          
+          (if (eq a nil)
+              (progn
+                (kde-switch-cpp-h)
+                (message "point is not in a method"))
+            (if (string-match "^\\(.*\\)::\\(.*\\)$" a)
+                (progn
+                  (setq class (match-string 1 a))
+                  (setq function (match-string 2 a))
+                  (kde-switch-cpp-h)
+                  (goto-char 0)
+                                        ; Look for beginning of class ("\\s-+" means whitespace including newlines)
+                  (re-search-forward
+                   (concat "\\(class\\|struct\\|namespace\\)\\s-+"
+                           "\\([A-Z_]+_EXPORT[A-Z_]*\\s-+\\)?"  ; allow for optional EXPORT macro
+                           class "\\b"                          ; the classname - with word separator
+                           "[^;]+{"                             ; the optional inheritance and the '{'
+                           ) nil t)                             ; no error, just return nil if not found
+
+                                        ; Look for function - with \\b prepended, unless this is about ~Foo.
+                  (setq functionregexp (kde-function-regexp-quote function))
+                  (and (not (string-match "^~" functionregexp))
+                       (setq functionregexp (concat "\\b" functionregexp)))
+                  ;; TODO keep looking, until we find a match that's not inside a comment
+                  (re-search-forward (concat functionregexp "[ \t]*(") nil t))
+                                        ; else: not a member method, maybe just a c function
+              (progn
+                (setq function a)
+                (kde-switch-cpp-h)
+                (goto-char 0)
+                (re-search-forward (concat "\\b" (kde-function-regexp-quote function) "[ \t]*(") nil t))
+              )
+            )
+          ))
     (if (string-match "\\.h$" n)
         (progn
 	  (let ((mup (method-under-point))
 		(sig "")
 		(pos 0))
         (setq namespace (car mup))
-	    (setq class (car (cdr mup)))
-	    (setq function (cdr (cdr mup)))
+	    (setq class (cadr mup))
+	    (setq function (cddr mup))
 	    (kde-switch-cpp-h)
 
         ;; First search with namespace prefixed
@@ -272,14 +315,27 @@ This function does not do any hidden buffer changes."
   (let* (
 	 (mup (method-under-point))
 	 (namespace (car mup))  ; will contain A::B::
-	 (class (car (cdr mup)))
-	 (function (cdr (cdr mup)))
+	 (class (cadr mup))
+	 (function (cddr mup))
 	 (file (buffer-file-name))
 	 (insertion-string (kde-function-impl-sig namespace class function))
+	 (function-sig (canonical-function-sig function))
 	 (msubstr nil)
 	 (start nil)
 	 (newcppfile nil)
+	 (baseclass nil)
 	 )
+    ; First, assemble the skeleton text into insertion-string
+    ; At this point it already contains the method signature
+
+    ; If constructor: add call to base class 
+    (and (stringp class)
+	 (string-match (concat "^ *" class "[ \\t]*(") function-sig) ; constructor
+	 (setq baseclass (baseclass-under-point))
+	 ; TODO: passing the parent parameter if baseclass starts with Q :)
+	 (setq insertion-string (concat insertion-string "\n    : " baseclass "()" )))
+
+    ; Method body
     (setq insertion-string 
 	  (concat insertion-string "\n{\n"
 		  (replace-in-string kde-make-member-default-impl "FUNCTION" 
@@ -287,7 +343,8 @@ This function does not do any hidden buffer changes."
 				     (replace-in-string insertion-string "\n" " " t)
 				     t)
 		  "}\n"))
-    ; move to next method, to be ready for next call
+
+    ; Move to next method, to be ready for next call
     (backward-char)                ; in case we're after the ';'
     (re-search-forward ";" nil t)  ; end of this method decl
     (let ((moveToNext t))
@@ -304,36 +361,36 @@ This function does not do any hidden buffer changes."
 	)
       )
 
-    (setq newcppfile (not (cdr (kde-file-get-cpp-h))))
-    (if (string-match "\\.h$" file)
+    ; Switch to .cpp if the declaration was in a header file
+    (if (member (concat "." (file-name-extension file)) sourcepair-header-extensions)
 	(kde-switch-cpp-h)
       )
-    (goto-char (point-max))    
+    ;(setq newcppfile (= (point-max) 1))
+    (goto-char (point-max))
     (kde-comments-begin)
     (kde-skip-blank-lines)
     (setq msubstr (buffer-substring (point-at-bol) (point-at-eol)))
-    (if (string-match "^#include.*moc.*" msubstr)
+    (if (string-match "^#include.*moc.*" msubstr) ; TODO refine regexp
 	(progn 
 	  (forward-line -1)
 	  (end-of-line)
-	  (insert "\n")))
-    (if (string-match "}" msubstr)
-	(progn
+	  (insert "\n"))
+    ; else
+      (progn
 	  (end-of-line)
 	  (insert "\n")
 	  (forward-line 1)
 	  ))
-    (when newcppfile
-      (insert "\n"))
     (insert insertion-string)
     (forward-char -3)
-    (c-indent-defun)   
+    (c-indent-defun)
+    ; Insert #include for the header if necessary
     (save-excursion
       (and (string-match ".*/" file)
 	   (setq file (replace-match "" t nil file)))
       (and (string-match "\\.h$" file)
-	   (functionp 'kdab-insert-include-file)
-	   (kdab-insert-include-file file 't nil)))
+	   (functionp 'kdab-insert-header-non-interactive)
+       (kdab-insert-header-non-interactive (file-name-sans-extension file))))
     (when (featurep 'fume-rescan-buffer)
       (fume-rescan-buffer))
     ))
@@ -383,14 +440,15 @@ This function does not do any hidden buffer changes."
   )
 
 
-; Inserts a kdDebug statement showing the name of the current method.
+; Inserts a kDebug statement showing the name of the current method.
 ; You need to create the empty line first.
-(defun insert-kdDebug ()
+(defun insert-kDebug ()
   (interactive)
-  (insert "kdDebug() << ")
-  ;; no unnecessary fume-* functions which aren't available on GNU/Emacs
-  (insert "k_funcinfo")
-  (insert " << endl;")
+  (if (and (boundp 'kdab-qt-version) (eq kdab-qt-version 4))
+      (insert "kDebug() << ")
+    (insert "kdDebug() << k_funcinfo "))
+  (insert "<< endl;")
+  (backward-char 8)
   )
 
 ; finds a string to be used in the header-protection function ( see below )
@@ -430,20 +488,25 @@ This function does not do any hidden buffer changes."
     )
   )
 
+;; Add (setq magic-parens-mode nil) to your .emacs (before loading this file)
+;; to disable the automatic spaces inside "( ... )" in C++ mode.
+;; This can also be enabled/disabled per project using  magic-parens-mode: t  in .emacs-dirvars.
+
 ; Makes '(' insert '(' or ' ( ' where appropiate
 (defun insert-parens (arg) (interactive "*P")
-  (if (not (c-in-literal))
+  (if (and (not (c-in-literal))
+           (boundp 'magic-parens-mode) magic-parens-mode)
       (let ((n nil) (except nil))
         (save-excursion
-          (setq n (or (progn (forward-char -2) (looking-at "if"))
-                      (progn (forward-char -1) (looking-at "for"))
-                      (progn (forward-char -1) (looking-at "case"))
-                      (progn (forward-char -1) (looking-at "while"))
+          (setq n (or (progn (forward-char -2) (looking-at "\\bif"))
+                      (progn (forward-char -1) (looking-at "\\bfor"))
+                      (progn (forward-char -1) (looking-at "\\bcase"))
+                      (progn (forward-char -1) (looking-at "\\bwhile"))
                       )
                 )
-          (setq except (or (progn (forward-char -2) (looking-at "kdDebug"))
-                           (looking-at "kdError")
-                           (progn (forward-char -2) (looking-at "kdWarning"))
+          (setq except (or (progn (forward-char -2) (looking-at "kDebug"))
+                           (looking-at "kError")
+                           (progn (forward-char -2) (looking-at "kWarning"))
 			   )
                 )
           )
@@ -461,7 +524,8 @@ This function does not do any hidden buffer changes."
   )
 
 (defun insert-parens2 (arg) (interactive "*P")
-  (if (not (c-in-literal))
+  (if (and (not (c-in-literal))
+           (boundp 'magic-parens-mode) magic-parens-mode)
       (let ((remv nil) (nospac nil))
         (forward-char -2)
         (setq remv (looking-at "( ")) ; () -> we'll have to remove that space
@@ -469,13 +533,13 @@ This function does not do any hidden buffer changes."
         (setq nospac ; no space to be added
               (or (looking-at " ")
                   (looking-at "(")
-                  (save-excursion ; check for kdDebug(123
+                  (save-excursion ; check for kDebug(123
                     (while (looking-at "[0-9]")
                       (forward-char -1))
                     (forward-char -7)
-                    (or (looking-at "kdDebug(")
-			(looking-at "kdError(")
-                           (progn (forward-char -2) (looking-at "kdWarning("))
+                    (or (looking-at "kDebug(")
+			(looking-at "kError(")
+                           (progn (forward-char -2) (looking-at "kWarning("))
 			   )
 		    )
                   )
@@ -616,7 +680,7 @@ This function does not do any hidden buffer changes."
   (let ((f (file-name-nondirectory (buffer-file-name)))
 	(objext nil))
 
-    (if (file-readable-p "Makefile.am")
+    (if (and (file-readable-p "Makefile.am") (not (file-readable-p "CMakeLists.txt")))
 	(setq objext "\.lo")
       (setq objext "\.o"))
     (if (string-match "\.cpp$" f) (setq f (replace-match objext t t f)))
@@ -637,12 +701,11 @@ This function does not do any hidden buffer changes."
 (defun scroll-other-up () (interactive) (scroll-other-window-down 1)) ; hehe :)
 (defun scroll-other-down () (interactive) (scroll-other-window 1))
 
-(defun match-paren (arg)
-  "Go to the matching parenthesis if on parenthesis otherwise insert %."
-  (interactive "p")
-  (cond ((looking-at "\\s\(") (forward-list 1) (backward-char 1))
-        ((looking-at "\\s\)") (forward-char 1) (backward-list 1))
-        (t (self-insert-command (or arg 1)))))
+(defun match-paren ()
+  "Go to the matching parenthesis if on parenthesis otherwise do nothing."
+  (interactive)
+  (cond ((looking-at "[ \t]*[\({]") (forward-sexp) (backward-char))
+	((looking-at "[\)}]") (forward-char) (backward-sexp))))
 
 (defun kde-start-c++-header ()
   "Start a new C++ header by inserting include guards ( see \
