@@ -38,7 +38,7 @@ public:
      * @param type      The type of this UMLAttribute.
      * @param iv        The initial value of the attribute.
      */
-    UMLAttribute(const UMLObject *parent, const QString& name,
+    UMLAttribute(UMLObject *parent, const QString& name,
                  Uml::IDType id = Uml::id_None,
                  Uml::Visibility s = Uml::Visibility::Private,
                  UMLObject *type = 0, const QString& iv = 0);
@@ -48,12 +48,12 @@ public:
      *
      * @param parent    The parent of this UMLAttribute.
      */
-    UMLAttribute(const UMLObject *parent);
+    UMLAttribute(UMLObject *parent);
 
     /**
      * Overloaded '==' operator
      */
-    bool operator==( UMLAttribute &rhs);
+    bool operator==(const UMLAttribute &rhs);
 
     /**
      * destructor.
@@ -64,7 +64,7 @@ public:
      * Copy the internal presentation of this object into the UMLAttribute
      * object.
      */
-    virtual void copyInto(UMLAttribute *rhs) const;
+    virtual void copyInto(UMLObject *lhs) const;
 
     /**
      * Reimplementation of method from UMLObject is required as
@@ -109,13 +109,13 @@ public:
     /**
      * Reimplement method from UMLObject.
      */
-    QString getFullyQualifiedName(const QString& separator = QString::null,
+    QString getFullyQualifiedName( const QString& separator = QString(),
                                   bool includeRoot = false) const;
 
     /**
      * Creates the <UML:Attribute> XMI element.
      */
-    void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
+    virtual void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
 
     /**
      * Display the properties configuration dialog for the attribute.
