@@ -58,7 +58,7 @@ bool AdaWriter::isOOClass(UMLClassifier *c) {
     if (ot == Uml::ot_Enum)
         return false;
     if (ot != Uml::ot_Class) {
-        kDebug() << "AdaWriter::isOOClass: unknown object type " << ot << endl;
+        uDebug() << "unknown object type " << ot;
         return false;
     }
     QString stype = c->getStereotype();
@@ -147,13 +147,13 @@ void AdaWriter::computeAssocTypeAndRole(UMLClassifier *c,
 
 void AdaWriter::writeClass(UMLClassifier *c) {
     if (!c) {
-        kDebug() << "Cannot write class of NULL concept!" << endl;
+        uDebug() << "Cannot write class of NULL concept!";
         return;
     }
 
     const bool isClass = !c->isInterface();
     QString classname = cleanName(c->getName());
-    QString fileName = packageName(c).lower();
+    QString fileName = packageName(c).toLower();
     fileName.replace('.', '-');
 
     //find an appropriate name for our file
@@ -177,7 +177,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     str = getHeadingFile(".ads");
     if (!str.isEmpty()) {
         str.replace(QRegExp("%filename%"), fileName);
-        str.replace(QRegExp("%filepath%"), file.name());
+        str.replace(QRegExp("%filepath%"), file.fileName());
         ada << str << endl;
     }
 
@@ -185,7 +185,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     UMLPackageList imports;
     findObjectsRelated(c, imports);
     if (imports.count()) {
-        for (UMLPackage *con = imports.first(); con; con = imports.next()) {
+        foreach (UMLPackage* con, imports ) {
             if (con->getBaseType() != Uml::ot_Datatype)
                 ada << "with " << packageName(con) << "; " << m_endl;
         }
@@ -197,7 +197,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     if (template_params.count()) {
         ada << getIndent() << "generic" << m_endl;
         m_indentLevel++;
-        for (UMLTemplate *t = template_params.first(); t; t = template_params.next()) {
+        foreach (UMLTemplate* t, template_params ) {
             QString formalName = t->getName();
             QString typeName = t->getTypeName();
             if (typeName == "class") {
@@ -207,8 +207,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
                 // Check whether it's a data type.
                 UMLClassifier *typeObj = t->getType();
                 if (typeObj == NULL) {
-                    kError() << "AdaWriter::writeClass(template_param "
-                    << typeName << "): typeObj is NULL" << endl;
+                    uError() << "template_param " << typeName << ": typeObj is NULL" << endl;
                     ada << getIndent() << "type " << formalName << " is new " << typeName
                     << " with private;  -- CHECK: codegen error"
                     << m_endl;
@@ -234,10 +233,10 @@ void AdaWriter::writeClass(UMLClassifier *c) {
         uint i = 0;
         ada << getIndent() << "type " << classname << " is (" << m_endl;
         m_indentLevel++;
-        for (UMLClassifierListItem *lit = litList.first(); lit; lit = litList.next()) {
+        foreach (UMLClassifierListItem* lit, litList ) {
             QString enumLiteral = cleanName(lit->getName());
             ada << getIndent() << enumLiteral;
-            if (++i < litList.count())
+            if (++i < ( uint )litList.count())
                 ada << "," << m_endl;
         }
         m_indentLevel--;
@@ -253,15 +252,14 @@ void AdaWriter::writeClass(UMLClassifier *c) {
         } else if(stype == "CORBAStruct") {
             if (isClass) {
                 UMLAttributeList atl = c->getAttributeList();
-                UMLAttribute *at;
                 ada << getIndent() << "type " << classname << " is record" << m_endl;
                 m_indentLevel++;
-                for (at = atl.first(); at; at = atl.next()) {
+                foreach (UMLAttribute* at,  atl ) {
                     QString name = cleanName(at->getName());
                     QString typeName = at->getTypeName();
                     ada << getIndent() << name << " : " << typeName;
                     QString initialVal = at->getInitialValue();
-                    if (initialVal.latin1() && ! initialVal.isEmpty())
+                    if (! initialVal.isEmpty() && ! initialVal.toLatin1().isEmpty())
                         ada << " := " << initialVal;
                     ada << ";" << m_endl;
                 }
@@ -310,18 +308,17 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     UMLAttributeList atl;
     if (isClass) {
         UMLAttributeList atpub;
-        atpub.setAutoDelete(false);
 
         atl = c->getAttributeList();
 
-        UMLAttribute *at;
-        for (at = atl.first(); at; at = atl.next()) {
-              if (at->getVisibility() == Uml::Visibility::Public)
+        foreach (UMLAttribute* at, atl ) {
+            if (at->getVisibility() == Uml::Visibility::Public)
                 atpub.append(at);
         }
         if (forceSections() || atpub.count())
             ada << getIndent() << "-- Accessors for public attributes:" << m_endl << m_endl;
-        for (at = atpub.first(); at; at = atpub.next()) {
+
+        foreach (UMLAttribute* at, atpub ) {
             QString member = cleanName(at->getName());
             ada << getIndent() << "procedure Set_" << member << " (";
             if (! at->getStatic())
@@ -338,16 +335,16 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     // Generate public operations.
     UMLOperationList opl(c->getOpList());
     UMLOperationList oppub;
-    oppub.setAutoDelete(false);
-    UMLOperation *op;
-    for (op = opl.first(); op; op = opl.next()) {
-         if (op->getVisibility() == Uml::Visibility::Public)
+    foreach (UMLOperation* op, opl ) {
+        if (op->getVisibility() == Uml::Visibility::Public)
             oppub.append(op);
     }
     if (forceSections() || oppub.count())
         ada << getIndent() << "-- Public methods:" << m_endl << m_endl;
-    for (op = oppub.first(); op; op = oppub.next())
+
+    foreach (UMLOperation* op, oppub ) {
         writeOperation(op, ada);
+    }
 
     m_indentLevel--;
     ada << getIndent() << "private" << m_endl << m_endl;
@@ -371,7 +368,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
 
     if (forceSections() || !aggregations.isEmpty()) {
         ada << getIndent() << "-- Aggregations:" << m_endl;
-        for (UMLAssociation *a = aggregations.first(); a; a = aggregations.next()) {
+        foreach (UMLAssociation *a , aggregations) {
             if (c != a->getObject(Uml::A))
                 continue;
             QString typeName, roleName;
@@ -382,7 +379,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     }
     if (forceSections() || !compositions.isEmpty()) {
         ada << getIndent() << "-- Compositions:" << m_endl;
-        for (UMLAssociation *a = compositions.first(); a; a = compositions.next()) {
+        foreach (UMLAssociation *a , compositions ) {
             if (c != a->getObject(Uml::A))
                 continue;
             QString typeName, roleName;
@@ -394,13 +391,12 @@ void AdaWriter::writeClass(UMLClassifier *c) {
 
     if (isClass && (forceSections() || atl.count())) {
         ada << getIndent() << "-- Attributes:" << m_endl;
-        UMLAttribute *at;
-        for (at = atl.first(); at; at = atl.next()) {
+        foreach (UMLAttribute* at, atl ) {
             if (at->getStatic())
                 continue;
             ada << getIndent() << cleanName(at->getName()) << " : "
             << at->getTypeName();
-            if (at && at->getInitialValue().latin1() && ! at->getInitialValue().isEmpty())
+            if (at && ! at->getInitialValue().isEmpty() && ! at->getInitialValue().toLatin1().isEmpty())
                 ada << " := " << at->getInitialValue();
             ada << ";" << m_endl;
         }
@@ -412,7 +408,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     ada << getIndent() << "end record;" << m_endl << m_endl;
     if (haveAttrs) {
         bool seen_static_attr = false;
-        for (UMLAttribute *at = atl.first(); at; at = atl.next()) {
+        foreach (UMLAttribute* at, atl ) {
             if (! at->getStatic())
                 continue;
             if (! seen_static_attr) {
@@ -423,7 +419,7 @@ void AdaWriter::writeClass(UMLClassifier *c) {
             if (at->getVisibility() == Uml::Visibility::Private)
                 ada << "-- Private:  ";
             ada << cleanName(at->getName()) << " : " << at->getTypeName();
-            if (at && at->getInitialValue().latin1() && ! at->getInitialValue().isEmpty())
+            if (at && ! at->getInitialValue().isEmpty() && ! at->getInitialValue().toLatin1().isEmpty() )
                 ada << " := " << at->getInitialValue();
             ada << ";" << m_endl;
         }
@@ -432,15 +428,15 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     }
     // Generate protected operations.
     UMLOperationList opprot;
-    opprot.setAutoDelete(false);
-    for (op = opl.first(); op; op = opl.next()) {
-      if (op->getVisibility() == Uml::Visibility::Protected)
+    foreach (UMLOperation* op,  opl ) {
+        if (op->getVisibility() == Uml::Visibility::Protected)
             opprot.append(op);
     }
     if (forceSections() || opprot.count())
         ada << getIndent() << "-- Protected methods:" << m_endl << m_endl;
-    for (op = opprot.first(); op; op = opprot.next())
+    foreach (UMLOperation* op, opprot ) {
         writeOperation(op, ada);
+    }
 
     // Generate private operations.
     // These are currently only generated as comments in the private part
@@ -449,17 +445,17 @@ void AdaWriter::writeClass(UMLClassifier *c) {
     // hand written code sections, private operations should be generated
     // into the package body.
     UMLOperationList oppriv;
-    oppriv.setAutoDelete(false);
-    for (op = opl.first(); op; op = opl.next()) {
-          const Uml::Visibility::Value vis = op->getVisibility();
-          if (vis == Uml::Visibility::Private ||
-              vis == Uml::Visibility::Implementation)
-            oppriv.append(op);
+    foreach (UMLOperation* op, opl ) {
+        const Uml::Visibility::Value vis = op->getVisibility();
+        if (vis == Uml::Visibility::Private ||
+            vis == Uml::Visibility::Implementation)
+        oppriv.append(op);
     }
     if (forceSections() || oppriv.count())
         ada << getIndent() << "-- Private methods:" << m_endl << m_endl;
-    for (op = oppriv.first(); op; op = oppriv.next())
+    foreach (UMLOperation* op, oppriv ) {
         writeOperation(op, ada, true);
+    }
 
     m_indentLevel--;
     ada << getIndent() << "end " << pkg << ";" << m_endl << m_endl;
@@ -492,7 +488,7 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
     if (atl.count()) {
         uint i = 0;
         m_indentLevel++;
-        for (UMLAttribute *at = atl.first(); at; at = atl.next()) {
+        foreach (UMLAttribute* at, atl ) {
             ada << getIndent();
             if (is_comment)
                 ada << "-- ";
@@ -507,7 +503,7 @@ void AdaWriter::writeOperation(UMLOperation *op, QTextStream &ada, bool is_comme
             ada << at->getTypeName();
             if (! at->getInitialValue().isEmpty())
                 ada << " := " << at->getInitialValue();
-            if (++i < atl.count()) //FIXME gcc warning
+            if (++i < ( uint )atl.count()) //FIXME gcc warning
                 ada << ";" << m_endl;
         }
         m_indentLevel--;
@@ -549,7 +545,7 @@ bool AdaWriter::isReservedKeyword(const QString & rPossiblyReservedKeyword) {
 
     QStringList::ConstIterator it;
     for (it = keywords.begin(); it != keywords.end(); ++it)
-        if ((*it).lower() == rPossiblyReservedKeyword.lower())
+        if ((*it).toLower() == rPossiblyReservedKeyword.toLower())
             return true;
 
     return false;
