@@ -23,10 +23,11 @@
 #include "../umlassociationlist.h"
 
 /**
-  * class ASWriter is a ActionScript code generator for UMLClassifier objects
-  * Just call writeClass and feed it a UMLClassifier;
-  */
-class ASWriter : public SimpleCodeGenerator {
+ * Class ASWriter is a ActionScript code generator for UMLClassifier objects.
+ * Just call writeClass and feed it a UMLClassifier.
+ */
+class ASWriter : public SimpleCodeGenerator
+{
     Q_OBJECT
 public:
 
@@ -34,18 +35,20 @@ public:
     virtual ~ASWriter();
 
     /**
-      * call this method to generate Actionscript code for a UMLClassifier
-      * @param c the class you want to generate code for.
-      */
+     * Call this method to generate Actionscript code for a UMLClassifier.
+     * @param c   the class you want to generate code for
+     */
     virtual void writeClass(UMLClassifier *c);
 
     /**
-     * returns "ActionScript"
+     * Returns "ActionScript".
+     * @return   the programming language identifier
      */
     virtual Uml::Programming_Language getLanguage();
 
     /**
-     * get list of reserved keywords
+     * Get list of reserved keywords.
+     * @return   the list of reserved keywords
      */
     virtual const QStringList reservedKeywords() const;
 
@@ -53,25 +56,25 @@ public:
 private:
 
     /**
-     * we do not want to write the comment "Private methods" twice
+     * We do not want to write the comment "Private methods" twice.
      */
     bool bPrivateSectionCommentIsWritten;
 
     /**
-      * write a list of class operations
-      *
-      * @param classname the name of the class
-      * @param opList the list of operations
-      * @param as output stream for the AS file
-      */
+     * Write a list of class operations.
+     *
+     * @param classname   the name of the class
+     * @param opList      the list of operations
+     * @param as          output stream for the AS file
+     */
     void writeOperations(QString classname, UMLOperationList *opList, QTextStream &as);
 
     /**
-     * write a list of associations
+     * Write a list of associations.
      *
-     * @param classname the name of the class
-     * @param assocList the list of associations
-     * @param as output stream for the AS file
+     * @param classname   the name of the class
+     * @param assocList   the list of associations
+     * @param as          output stream for the AS file
      */
     void writeAssociation(QString& classname, UMLAssociationList& assoclist , QTextStream &as);
 
