@@ -1,14 +1,15 @@
 /***************************************************************************
-                          javawriter.cpp  -  description
+                          javawriter.cpp
     This is the "old" code generator that does not support code editing
     in the Modeller but uses significantly less file space because the
     source code is not replicated in the XMI file.
-                             -------------------
-    copyright            : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
-***************************************************************************/
 
-/***************************************************************************
+    Copyright (C) 2003       Brian Thomas
+                             <brian.thomas@gsfc.nasa.gov>
+              (C) 2004-2008  Umbrello UML Modeller Authors
+                             <uml-devel@uml.sf.net>
+
+ ***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,12 +21,13 @@
 // own header
 #include "javawriter.h"
 // qt includes
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qregexp.h>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QRegExp>
 // kde includes
 #include <kdebug.h>
 // app includes
+#include "codegen_utils.h"
 #include "../umldoc.h"
 #include "../classifier.h"
 #include "../operation.h"
@@ -34,27 +36,30 @@
 #include "../template.h"
 #include "../umltemplatelist.h"
 
-JavaWriter::JavaWriter() {
+JavaWriter::JavaWriter()
+{
     startline = m_endl + m_indentation;
 }
 
-JavaWriter::~JavaWriter() {}
+JavaWriter::~JavaWriter()
+{
+}
 
-Uml::Programming_Language JavaWriter::getLanguage() {
+Uml::Programming_Language JavaWriter::getLanguage()
+{
     return Uml::pl_Java;
 }
 
 void JavaWriter::writeClass(UMLClassifier *c)
 {
-
     if (!c) {
-        kDebug()<<"Cannot write class of NULL concept!\n";
+        uDebug()<<"Cannot write class of NULL concept!\n";
         return;
     }
 
     isInterface = c->isInterface();
 
-    QString fileName = cleanName(c->getName().lower());
+    QString fileName = cleanName(c->getName().toLower());
 
     //find an appropriate name for our file
     fileName = findFileName(c,".java");
@@ -77,16 +82,10 @@ void JavaWriter::writeClass(UMLClassifier *c)
     UMLAttributeList  atl;
     UMLAttributeList  atpub, atprot, atpriv;
     UMLAttributeList  final_atpub, final_atprot, final_atpriv;
-    atpub.setAutoDelete(false);
-    final_atpub.setAutoDelete(false);
-    atprot.setAutoDelete(false);
-    final_atprot.setAutoDelete(false);
-    atpriv.setAutoDelete(false);
-    final_atpriv.setAutoDelete(false);
 
     if (!isInterface) {
         UMLAttributeList atl = c->getAttributeList();
-        for (UMLAttribute *at = atl.first(); at ; at = atl.next()) {
+        foreach (UMLAttribute *at ,  atl ) {
             switch(at->getVisibility())
             {
               case Uml::Visibility::Public:
@@ -135,13 +134,13 @@ void JavaWriter::writeClass(UMLClassifier *c)
     //try to find a heading file (license, coments, etc)
     QString str;
     str = getHeadingFile(".java");
-    if(!str.isEmpty()) {
+    if (!str.isEmpty()) {
         str.replace(QRegExp("%filename%"),fileName);
-        str.replace(QRegExp("%filepath%"),file.name());
+        str.replace(QRegExp("%filepath%"),file.fileName());
         java<<str<<m_endl;
     }
 
-    if(!c->getPackage().isEmpty())
+    if (!c->getPackage().isEmpty())
         java<<"package "<<c->getPackage()<<";"<<m_endl;
 
     // IMPORT statements
@@ -157,7 +156,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
     //only import classes in a different package as this class
     UMLPackageList imports;
     findObjectsRelated(c,imports);
-    for (UMLPackage *con = imports.first(); con; con = imports.next()) {
+    foreach (UMLPackage* con,  imports ) {
         if (con->getBaseType() == Uml::ot_Datatype)
             continue;
         QString pkg = con->getPackage();
@@ -196,7 +195,7 @@ void JavaWriter::writeClass(UMLClassifier *c)
 
     // Constructors: anything we more we need to do here ?
     //
-    if(!isInterface)
+    if (!isInterface)
         writeConstructor(c, java);
 
     // METHODS
@@ -205,7 +204,6 @@ void JavaWriter::writeClass(UMLClassifier *c)
     // write comment for section IF needed
     if (forceDoc() || hasAccessorMethods || hasOperationMethods)
     {
-
         java<<startline;
         writeComment("", m_indentation, java);
         writeComment("Methods", m_indentation, java);
@@ -261,13 +259,12 @@ void JavaWriter::writeClass(UMLClassifier *c)
 
 void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
 {
-
     QString classname = cleanName(c->getName()); // our class name
 
     // write documentation for class, if any, first
-    if(forceDoc() || !c->getDoc().isEmpty())
+    if (forceDoc() || !c->getDoc().isEmpty())
     {
-        if(isInterface)
+        if (isInterface)
             writeDocumentation("Interface "+classname,c->getDoc(),"","",java);
         else
             writeDocumentation("Class "+classname,c->getDoc(),"","",java);
@@ -276,7 +273,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
     }
 
     // Now write the actual class declaration
-    QString scope = ""; // = scopeToJavaDecl(c->getVisibility());
+    QString scope = ""; // = c->getVisibility().toString();
     if (c->getVisibility() != Uml::Visibility::Public) {
         // We should emit a warning in here .. java doesn't like to allow
         // private/protected classes. The best we can do (I believe)
@@ -287,7 +284,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
         scope = "public ";
 
     java<<((c->getAbstract() && !isInterface) ? QString("abstract ") : QString(""))<<scope;
-    if(isInterface)
+    if (isInterface)
         java<<"interface ";
     else
         java<<"class ";
@@ -298,26 +295,27 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
     UMLTemplateList template_params = c->getTemplateList();
     if (template_params.count()) {
         java << "<";
-        for (UMLTemplate *t = template_params.first(); t; ) {
+        for (UMLTemplateListIt tlit( template_params ); tlit.hasNext(); ) {
+            UMLTemplate* t = tlit.next();
             QString formalName = t->getName();
             java <<  formalName;
             QString typeName = t->getTypeName();
             if (typeName != "class") {
                 java << " extends " << typeName;
             }
-            if ((t = template_params.next()) != NULL)
+            if ( tlit.hasNext() ) {
+                tlit.next();
                 java << ", ";
+            }
         }
         java << ">" << m_endl;
     }
 
     // write inheritances out
-    UMLClassifier *concept;
     UMLClassifierList superclasses = c->findSuperClassConcepts(UMLClassifier::CLASS);
 
     int i = 0;
-    for (concept= superclasses.first(); concept; concept = superclasses.next())
-    {
+    foreach ( UMLClassifier *concept, superclasses ) {
         if (i == 0)
         {
             java<< " extends ";
@@ -333,8 +331,7 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
 
     UMLClassifierList superInterfaces = c->findSuperClassConcepts(UMLClassifier::INTERFACE);
     i = 0;
-    for (concept= superInterfaces.first(); concept; concept = superInterfaces.next())
-    {
+    foreach ( UMLClassifier *concept, superInterfaces ) {
         if (i == 0)
         {
             if (isInterface)
@@ -356,39 +353,34 @@ void JavaWriter::writeClassDecl(UMLClassifier *c, QTextStream &java)
 void JavaWriter::writeAttributeDecls(UMLAttributeList &atpub, UMLAttributeList &atprot,
                                      UMLAttributeList &atpriv, QTextStream &java )
 {
-    UMLAttribute *at;
-
-    for(at=atpub.first(); at; at=atpub.next())
-    {
+    foreach (UMLAttribute *at, atpub ) {
         QString documentation = at->getDoc();
         QString staticValue = at->getStatic() ? "static " : "";
         QString typeName = fixTypeName(at->getTypeName());
         QString initialValue = fixInitialStringDeclValue(at->getInitialValue(), typeName);
-        if(!documentation.isEmpty())
+        if (!documentation.isEmpty())
             writeComment(documentation, m_indentation, java, true);
         java<<startline<<staticValue<<"public "<<typeName<<" "<<cleanName(at->getName())
         <<(initialValue.isEmpty()?QString(""):QString(" = ") + initialValue)<<";";
     }
 
-    for(at=atprot.first();at;at=atprot.next())
-    {
+    foreach (UMLAttribute *at, atprot ){
         QString documentation = at->getDoc();
         QString typeName = fixTypeName(at->getTypeName());
         QString staticValue = at->getStatic() ? "static " : "";
         QString initialValue = fixInitialStringDeclValue(at->getInitialValue(), typeName);
-        if(!documentation.isEmpty())
+        if (!documentation.isEmpty())
             writeComment(documentation, m_indentation, java, true);
         java<<startline<<staticValue<<"protected "<<typeName<<" "<<cleanName(at->getName())
         <<(initialValue.isEmpty()?QString(""):QString(" = ") + initialValue)<<";";
     }
 
-    for(at=atpriv.first();at;at=atpriv.next())
-    {
+    foreach (UMLAttribute *at, atpriv ) {
         QString documentation = at->getDoc();
         QString typeName = fixTypeName(at->getTypeName());
         QString staticValue = at->getStatic() ? "static " : "";
         QString initialValue = fixInitialStringDeclValue(at->getInitialValue(), typeName);
-        if(!documentation.isEmpty())
+        if (!documentation.isEmpty())
             writeComment(documentation, m_indentation, java, true);
         java<<startline<<staticValue<<"private "<<typeName<<" "<<cleanName(at->getName())
         <<(initialValue.isEmpty()?QString(""):QString(" = ") + initialValue)<<";";
@@ -398,16 +390,12 @@ void JavaWriter::writeAttributeDecls(UMLAttributeList &atpub, UMLAttributeList &
 
 void JavaWriter::writeAttributeMethods(UMLAttributeList &atpub, Uml::Visibility visibility, QTextStream &java)
 {
-
-    UMLAttribute *at;
-    for(at=atpub.first(); at; at=atpub.next())
-    {
+    foreach (UMLAttribute *at, atpub ){
         QString fieldName = cleanName(at->getName());
         // force capitalizing the field name, this is silly,
         // from what I can tell, this IS the default behavior for
         // cleanName. I dunno why its not working -b.t.
-        fieldName.stripWhiteSpace();
-        fieldName.replace(0,1,fieldName.at(0).upper());
+        fieldName.replace(0,1,fieldName.at(0).toUpper());
 
         writeSingleAttributeAccessorMethods(at->getTypeName(),
                                             cleanName(at->getName()),
@@ -415,7 +403,6 @@ void JavaWriter::writeAttributeMethods(UMLAttributeList &atpub, Uml::Visibility
                                             at->getDoc(),
                                             visibility, Uml::chg_Changeable, at->getStatic(), java);
     }
-
 }
 
 void JavaWriter::writeComment(const QString &comment, const QString &myIndent,
@@ -426,31 +413,31 @@ void JavaWriter::writeComment(const QString &comment, const QString &myIndent,
     // need to resolve for using with MAC/WinDoze eventually I assume
     if (comment.contains(QRegExp("\n"))) {
 
-        if(javaDocStyle)
+        if (javaDocStyle)
             java << myIndent << "/**" << m_endl;
-        QStringList lines = QStringList::split( "\n", comment);
-        for(uint i= 0; i < lines.count(); i++)
+        QStringList lines = comment.split( "\n" );
+        for (int i= 0; i < lines.count(); i++)
         {
             writeBlankLine(java);
-            if(javaDocStyle)
+            if (javaDocStyle)
                 java<<myIndent<<" * ";
             else
                 java<<myIndent<<"// ";
             java << lines[i];
         }
-        if(javaDocStyle)
+        if (javaDocStyle)
             java << myIndent << " */" << m_endl;
     } else {
         // this should be more fancy in the future, breaking it up into 80 char
         // lines so that it doesn't look too bad
         writeBlankLine(java);
-        if(javaDocStyle)
+        if (javaDocStyle)
             java << myIndent << "/**" << m_endl << myIndent << " *";
         else
             java<<myIndent<<"//";
         if(comment.length() > 0)
             java << " " << comment;
-        if(javaDocStyle)
+        if (javaDocStyle)
             java << m_endl << myIndent << " */";
     }
 }
@@ -465,8 +452,8 @@ void JavaWriter::writeDocumentation(QString header, QString body, QString end, Q
         java<<formatDoc(body, indent+" * ");
     if (!end.isEmpty())
     {
-        QStringList lines = QStringList::split( "\n", end);
-        for(uint i= 0; i < lines.count(); i++)
+        QStringList lines = end.split( "\n" );
+        for (int i= 0; i < lines.count(); i++)
             java<<formatDoc(lines[i], indent+" * ");
     }
     java<<indent<<" */";
@@ -474,12 +461,10 @@ void JavaWriter::writeDocumentation(QString header, QString body, QString end, Q
 
 void JavaWriter::writeAssociationDecls(UMLAssociationList associations, Uml::IDType id, QTextStream &java)
 {
-
-    if( forceSections() || !associations.isEmpty() )
+    if ( forceSections() || !associations.isEmpty() )
     {
         bool printRoleA = false, printRoleB = false;
-        for(UMLAssociation *a = associations.first(); a; a = associations.next())
-        {
+        foreach (UMLAssociation *a , associations ) {
             // it may seem counter intuitive, but you want to insert the role of the
             // *other* class into *this* class.
             if (a->getObjectId(Uml::A) == id)
@@ -518,7 +503,7 @@ void JavaWriter::writeAssociationRoleDecl(QString fieldClassName,
     if (roleName.isEmpty())
         return;
 
-    QString scope = scopeToJavaDecl(visib);
+    QString scope = visib.toString();
 
     // always put space between this and prior decl, if any
     writeBlankLine(java);
@@ -529,14 +514,14 @@ void JavaWriter::writeAssociationRoleDecl(QString fieldClassName,
     // declare the association based on whether it is this a single variable
     // or a List (Vector). One day this will be done correctly with special
     // multiplicity object that we don't have to figure out what it means via regex.
-    if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
+    if (multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).lower());
+        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).toLower());
         java<<startline<<scope<<" "<<fieldClassName<<" "<<fieldVarName<<";";
     }
     else
     {
-        QString fieldVarName = roleName.lower() + "Vector";
+        QString fieldVarName = roleName.toLower() + "Vector";
         java<<startline<<scope<<" Vector "<<fieldVarName<<" = new Vector();";
         // from here we could initialize default values, or put in an init() section
         // of the constructors
@@ -546,17 +531,16 @@ void JavaWriter::writeAssociationRoleDecl(QString fieldClassName,
 
 void JavaWriter::writeAssociationMethods (UMLAssociationList associations, UMLClassifier *thisClass, QTextStream &java)
 {
-    if( forceSections() || !associations.isEmpty() )
-    {
-        for(UMLAssociation *a = associations.first(); a; a = associations.next())
-        {
+    if ( forceSections() || !associations.isEmpty() ) {
+
+        foreach(UMLAssociation *a , associations ) {
 
             // insert the methods to access the role of the other
             // class in the code of this one
             if (a->getObjectId(Uml::A) == thisClass->getID())
             {
                 // only write out IF there is a rolename given
-                if(!a->getRoleName(Uml::B).isEmpty()) {
+                if (!a->getRoleName(Uml::B).isEmpty()) {
                     QString fieldClassName = getUMLObjectName(a->getObject(Uml::B));
                     writeAssociationRoleMethod(fieldClassName,
                                                a->getRoleName(Uml::B),
@@ -569,7 +553,7 @@ void JavaWriter::writeAssociationMethods (UMLAssociationList associations, UMLCl
             if (a->getObjectId(Uml::B) == thisClass->getID())
             {
                 // only write out IF there is a rolename given
-                if(!a->getRoleName(Uml::A).isEmpty()) {
+                if (!a->getRoleName(Uml::A).isEmpty()) {
                     QString fieldClassName = getUMLObjectName(a->getObject(Uml::A));
                     writeAssociationRoleMethod(fieldClassName, a->getRoleName(Uml::A),
                                                a->getMulti(Uml::A),
@@ -588,15 +572,15 @@ void JavaWriter::writeAssociationRoleMethod (QString fieldClassName, QString rol
         QString description, Uml::Visibility visib, Uml::Changeability_Type change,
         QTextStream &java)
 {
-    if(multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
+    if (multi.isEmpty() || multi.contains(QRegExp("^[01]$")))
     {
-        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).lower());
+        QString fieldVarName = "m_" + roleName.replace(0, 1, roleName.left(1).toLower());
         writeSingleAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
                                             description, visib, change, false, java);
     }
     else
     {
-        QString fieldVarName = roleName.lower() + "Vector";
+        QString fieldVarName = roleName.toLower() + "Vector";
         writeVectorAttributeAccessorMethods(fieldClassName, fieldVarName, roleName,
                                             description, visib, change, java);
     }
@@ -607,10 +591,9 @@ void JavaWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QS
         Uml::Visibility visibility, Uml::Changeability_Type changeType,
         QTextStream &java)
 {
-
     fieldClassName = fixTypeName(fieldClassName);
-    fieldName = capitaliseFirstLetter(fieldName);
-    QString strVis = scopeToJavaDecl(visibility);
+    fieldName = Codegen_Utils::capitalizeFirstLetter(fieldName);
+    QString strVis = visibility.toString();
 
     // ONLY IF changeability is NOT Frozen
     if (changeType != Uml::chg_Frozen)
@@ -639,16 +622,14 @@ void JavaWriter::writeVectorAttributeAccessorMethods (QString fieldClassName, QS
     writeBlankLine(java);
 }
 
-
 void JavaWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QString fieldVarName,
         QString fieldName, QString description,
         Uml::Visibility visibility, Uml::Changeability_Type change,
         bool isFinal, QTextStream &java)
 {
-
-    QString strVis = scopeToJavaDecl(visibility);
+    QString strVis = visibility.toString();
     fieldClassName = fixTypeName(fieldClassName);
-    fieldName = capitaliseFirstLetter(fieldName);
+    fieldName = Codegen_Utils::capitalizeFirstLetter(fieldName);
 
     // set method
     if (change == Uml::chg_Changeable && !isFinal) {
@@ -668,9 +649,7 @@ void JavaWriter::writeSingleAttributeAccessorMethods(QString fieldClassName, QSt
 
 void JavaWriter::writeConstructor(UMLClassifier *c, QTextStream &java)
 {
-
-    if (forceDoc())
-    {
+    if (forceDoc()) {
         java<<startline;
         writeComment("", m_indentation, java);
         writeComment("Constructors", m_indentation, java);
@@ -681,7 +660,6 @@ void JavaWriter::writeConstructor(UMLClassifier *c, QTextStream &java)
     // write the first constructor
     QString className = cleanName(c->getName());
     java<<m_indentation<<"public "<<className<<" () { };";
-
 }
 
 // IF the type is "string" we need to declare it as
@@ -698,7 +676,8 @@ QString JavaWriter::fixTypeName(const QString& string)
     return string;
 }
 
-QStringList JavaWriter::defaultDatatypes() {
+QStringList JavaWriter::defaultDatatypes()
+{
     QStringList l;
     l.append("int");
     l.append("char");
@@ -725,10 +704,9 @@ bool JavaWriter::compareJavaMethod(UMLOperation *op1, UMLOperation *op2)
     UMLAttributeList atl2 = op2->getParmList();
     if (atl1.count() != atl2.count())
         return false;
-    UMLAttribute *at1;
-    UMLAttribute *at2;
-    for (at1  = atl1.first(), at2 = atl2.first(); at1 && at2 ; at1 = atl1.next(),at2 = atl2.next())
-    {
+    for (UMLAttributeListIt atl1It( atl1 ), atl2It( atl2 ); atl1It.hasNext() && atl2It.hasNext(); ) {
+        UMLAttribute *at1 = atl1It.next();
+        UMLAttribute *at2 = atl2It.next();
         if (at1->getTypeName() != at2->getTypeName())
             return false;
     }
@@ -738,7 +716,7 @@ bool JavaWriter::compareJavaMethod(UMLOperation *op1, UMLOperation *op2)
 
 bool JavaWriter::javaMethodInList(UMLOperation *umlOp, UMLOperationList &opl)
 {
-    for (UMLOperation *op = opl.first(); op; op = opl.next()) {
+    foreach (UMLOperation *op , opl ) {
         if (JavaWriter::compareJavaMethod(op, umlOp)) {
             return true;
         }
@@ -750,11 +728,11 @@ void JavaWriter::getSuperImplementedOperations(UMLClassifier *c, UMLOperationLis
 {
     UMLClassifierList superClasses = c->findSuperClassConcepts();
 
-    for (UMLClassifier *concept= superClasses.first(); concept; concept = superClasses.next())
-    {
+    foreach (UMLClassifier *concept, superClasses) {
+
         getSuperImplementedOperations(concept, yetImplementedOpList, toBeImplementedOpList, (concept->isInterface() && noClassInPath));
         UMLOperationList opl = concept->getOpList();
-        for (UMLOperation *op = opl.first(); op; op = opl.next()) {
+        foreach (UMLOperation *op , opl ) {
             if (concept->isInterface() && noClassInPath) {
                 if (!JavaWriter::javaMethodInList(op,toBeImplementedOpList))
                     toBeImplementedOpList.append(op);
@@ -775,8 +753,7 @@ void JavaWriter::getInterfacesOperationsToBeImplemented(UMLClassifier *c, UMLOpe
     UMLOperationList toBeImplementedOpList;
 
     getSuperImplementedOperations(c,yetImplementedOpList, toBeImplementedOpList);
-    for (UMLOperation *op = toBeImplementedOpList.first(); op; op = toBeImplementedOpList.next())
-    {
+    foreach (UMLOperation *op , toBeImplementedOpList) {
         if ( ! JavaWriter::javaMethodInList(op, yetImplementedOpList) && ! JavaWriter::javaMethodInList(op, opList) )
             opList.append(op);
     }
@@ -785,16 +762,13 @@ void JavaWriter::getInterfacesOperationsToBeImplemented(UMLClassifier *c, UMLOpe
 void JavaWriter::writeOperations(UMLClassifier *c, QTextStream &java) {
     UMLOperationList opl;
     UMLOperationList oppub,opprot,oppriv;
-    oppub.setAutoDelete(false);
-    opprot.setAutoDelete(false);
-    oppriv.setAutoDelete(false);
 
     //sort operations by scope first and see if there are abstract methods
     opl = c->getOpList();
     if (! c->isInterface()) {
         getInterfacesOperationsToBeImplemented(c, opl);
     }
-    for (UMLOperation *op = opl.first(); op; op = opl.next()) {
+    foreach (UMLOperation *op , opl ) {
         switch(op->getVisibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
@@ -840,34 +814,32 @@ void JavaWriter::writeOperations(UMLClassifier *c, QTextStream &java) {
 
 }
 
-void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
-    UMLOperation *op;
+void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java)
+{
     UMLAttributeList atl;
-    UMLAttribute *at;
     int i,j;
     QString str;
 
     // generate method decl for each operation given
-    for( op=oplist.first(); op ;op=oplist.next())
-    {
+    foreach( UMLOperation* op ,  oplist ){
 
-        QString returnStr = "";
+        QString doc = "";
         // write documentation
 
         QString methodReturnType = fixTypeName(op->getTypeName());
-        if(methodReturnType != "void")
-            returnStr += "@return       "+methodReturnType+"\n";
+        if (methodReturnType != "void")
+            doc += "@return       " + methodReturnType + '\n';
 
         str = ""; // reset for next method
         str += ((op->getAbstract() && !isInterface) ? "abstract ":"");
-        str += scopeToJavaDecl(op->getVisibility()) + ' ';
+        str += op->getVisibility().toString() + ' ';
         str += (op->getStatic() ? "static ":"");
         str += methodReturnType + ' ' +cleanName(op->getName()) + "( ";
 
         atl = op->getParmList();
         i= atl.count();
         j=0;
-        for (at = atl.first(); at; at = atl.next(), j++) {
+        foreach ( UMLAttribute* at , atl ) {
             QString typeName = fixTypeName(at->getTypeName());
             QString atName = cleanName(at->getName());
             str += typeName + ' ' + atName +
@@ -875,68 +847,52 @@ void JavaWriter::writeOperations(UMLOperationList &oplist, QTextStream &java) {
                     (QString(" = ")+at->getInitialValue()) :
                     QString(""))
                    + ((j < i-1)?", ":"");
-            returnStr += "@param        "+atName+' '+at->getDoc()+"\n";
+            doc += "@param        " + atName + ' ' + at->getDoc() + '\n';
+            j++;
         }
+        doc = doc.remove(doc.size() - 1, 1);  // remove last endl of comment
         str+= " )";
 
         // method only gets a body IF its not abstract
         if (op->getAbstract() || isInterface)
             str+=";\n\n"; // terminate now
-        else
-            str+=startline+"{\n\n"+m_indentation+"}\n\n"; // empty method body
+        else {
+            str += startline + '{' + m_endl;
+            QString sourceCode = op->getSourceCode();
+            if (sourceCode.isEmpty()) {
+                // empty method body - TODO: throw exception
+            }
+            else {
+                str += formatSourceCode(sourceCode, m_indentation + m_indentation);
+            }
+            str += m_indentation + '}' + m_endl + m_endl;
+        }
 
         // write it out
-        writeDocumentation("", op->getDoc(), returnStr, m_indentation, java);
-        java<<startline<<str;
+        writeDocumentation("", op->getDoc(), doc, m_indentation, java);
+        java << startline << str;
     }
 }
 
-QString JavaWriter::fixInitialStringDeclValue(QString value, QString type)
+QString JavaWriter::fixInitialStringDeclValue(const QString& val, const QString& type)
 {
+    QString value = val;
     // check for strings only
     if (!value.isEmpty() && type == "String") {
-        if (!value.startsWith("\""))
-            value.prepend("\"");
-        if (!value.endsWith("\""))
-            value.append("\"");
+        if (!value.startsWith('"'))
+            value.prepend('"');
+        if (!value.endsWith('"'))
+            value.append('"');
     }
     return value;
 }
 
-QString JavaWriter::scopeToJavaDecl(Uml::Visibility scope)
-{
-    QString scopeString;
-    switch(scope)
-    {
-      case Uml::Visibility::Public:
-        scopeString = "public";
-        break;
-      case Uml::Visibility::Protected:
-        scopeString = "protected";
-        break;
-      case Uml::Visibility::Private:
-    default:
-        scopeString = "private";
-        break;
-    }
-    return scopeString;
-}
-
 // methods like this _shouldn't_ be needed IF we properly did things thruought the code.
 QString JavaWriter::getUMLObjectName(UMLObject *obj)
 {
     return(obj!=0)?obj->getName():QString("NULL");
 }
 
-QString JavaWriter::capitaliseFirstLetter(QString string)
-{
-    // we could lowercase everything tostart and then capitalize? Nah, it would
-    // screw up formatting like getMyRadicalVariable() to getMyradicalvariable(). Bah.
-    QChar firstChar = string.at(0);
-    string.replace( 0, 1, firstChar.upper());
-    return string;
-}
-
 void JavaWriter::writeBlankLine(QTextStream &java)
 {
     java<<m_endl;
