@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006                                                    *
+ *   copyright (C) 2006-2007                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -31,7 +31,6 @@
 #include "../operation.h"
 #include "../template.h"
 #include "../umlnamespace.h"
-#include "classifierinfo.h"
 
 const QString PascalWriter::defaultPackageSuffix = "_Holder";
 
@@ -40,9 +39,6 @@ PascalWriter::PascalWriter() {
 
 PascalWriter::~PascalWriter() {}
 
-/**
- * returns "Pascal"
- */
 Uml::Programming_Language PascalWriter::getLanguage() {
     return Uml::pl_Pascal;
 }
@@ -55,7 +51,7 @@ bool PascalWriter::isOOClass(UMLClassifier *c) {
     if (ot == Uml::ot_Enum)
         return false;
     if (ot != Uml::ot_Class) {
-        kDebug() << "PascalWriter::isOOClass: unknown object type " << ot << endl;
+        uDebug() << "unknown object type " << ot;
         return false;
     }
     QString stype = c->getStereotype();
@@ -122,13 +118,13 @@ void PascalWriter::computeAssocTypeAndRole
 
 void PascalWriter::writeClass(UMLClassifier *c) {
     if (!c) {
-        kDebug() << "Cannot write class of NULL concept!" << endl;
+        uDebug() << "Cannot write class of NULL concept!";
         return;
     }
 
     const bool isClass = !c->isInterface();
     QString classname = cleanName(c->getName());
-    QString fileName = qualifiedName(c).lower();
+    QString fileName = qualifiedName(c).toLower();
     fileName.replace('.', '-');
 
     //find an appropriate name for our file
@@ -152,7 +148,7 @@ void PascalWriter::writeClass(UMLClassifier *c) {
     str = getHeadingFile(".pas");
     if (!str.isEmpty()) {
         str.replace(QRegExp("%filename%"), fileName);
-        str.replace(QRegExp("%filepath%"), file.name());
+        str.replace(QRegExp("%filepath%"), file.fileName());
         pas << str << endl;
     }
 
@@ -165,7 +161,7 @@ void PascalWriter::writeClass(UMLClassifier *c) {
     if (imports.count()) {
         pas << "uses" << m_endl;
         bool first = true;
-        for (UMLPackage *con = imports.first(); con; con = imports.next()) {
+        foreach (UMLPackage* con, imports ) {
             if (con->getBaseType() != Uml::ot_Datatype) {
                 if (first)
                     first = false;
@@ -185,10 +181,10 @@ void PascalWriter::writeClass(UMLClassifier *c) {
         uint i = 0;
         pas << getIndent() << classname << " = (" << m_endl;
         m_indentLevel++;
-        for (UMLClassifierListItem *lit = litList.first(); lit; lit = litList.next()) {
+        foreach (UMLClassifierListItem *lit , litList ) {
             QString enumLiteral = cleanName(lit->getName());
             pas << getIndent() << enumLiteral;
-            if (++i < litList.count())
+            if (++i < ( uint )litList.count())
                 pas << "," << m_endl;
         }
         m_indentLevel--;
@@ -204,15 +200,15 @@ void PascalWriter::writeClass(UMLClassifier *c) {
             pas << getIndent() << "// " << stype << " is Not Yet Implemented" << m_endl << m_endl;
         } else if(stype == "CORBAStruct") {
             if (isClass) {
-                UMLAttribute *at;
+
                 pas << getIndent() << classname << " = record" << m_endl;
                 m_indentLevel++;
-                for (at = atl.first(); at; at = atl.next()) {
+                foreach (UMLAttribute* at , atl ) {
                     QString name = cleanName(at->getName());
                     QString typeName = at->getTypeName();
                     pas << getIndent() << name << " : " << typeName;
                     QString initialVal = at->getInitialValue();
-                    if (initialVal.latin1() && ! initialVal.isEmpty())
+                    if (!initialVal.isEmpty())
                         pas << " := " << initialVal;
                     pas << ";" << m_endl;
                 }
@@ -249,62 +245,61 @@ void PascalWriter::writeClass(UMLClassifier *c) {
     }
     pas << m_endl;
 
-    ClassifierInfo info(c);
-    UMLAttributeList atpub = info.atpub;
+    UMLAttributeList atpub = c->getAttributeList(Uml::Visibility::Public);
     if (isClass && (forceSections() || atpub.count())) {
         pas << getIndent() << "// Public attributes:" << m_endl;
-        UMLAttribute *at;
-        for (at = atpub.first(); at; at = atpub.next()) {
+
+        foreach ( UMLAttribute* at  , atpub ) {
             // if (at->getStatic())
             //     continue;
             pas << getIndent() << cleanName(at->getName()) << " : "
                 << at->getTypeName();
-            if (at && at->getInitialValue().latin1() && ! at->getInitialValue().isEmpty())
+            if (at && !at->getInitialValue().isEmpty())
                 pas << " := " << at->getInitialValue();
             pas << ";" << m_endl;
         }
     }
-    bool haveAttrs = (isClass && atl.count());
+    //bool haveAttrs = (isClass && atl.count());
 
     // Generate public operations.
     UMLOperationList opl(c->getOpList());
     UMLOperationList oppub;
-    oppub.setAutoDelete(false);
-    UMLOperation *op;
-    for (op = opl.first(); op; op = opl.next()) {
+
+    foreach (UMLOperation* op , opl ) {
          if (op->getVisibility() == Uml::Visibility::Public)
             oppub.append(op);
     }
     if (forceSections() || oppub.count())
         pas << getIndent() << "// Public methods:" << m_endl << m_endl;
-    for (op = oppub.first(); op; op = oppub.next())
+    foreach (UMLOperation* op , oppub )
         writeOperation(op, pas);
 
-    if (info.atprot.count()) {
+    UMLAttributeList atprot = c->getAttributeList(Uml::Visibility::Protected);
+    if (atprot.count()) {
         pas << "protected" << m_endl << m_endl;
-        UMLAttribute *at;
-        UMLAttributeList atprot = info.atprot;
-        for (at = atprot.first(); at; at = atprot.next()) {
+
+        foreach (UMLAttribute*  at , atprot ) {
             // if (at->getStatic())
             //     continue;
             pas << getIndent() << cleanName(at->getName()) << " : "
                 << at->getTypeName();
-            if (at && at->getInitialValue().latin1() && ! at->getInitialValue().isEmpty())
+            if (at && !at->getInitialValue().isEmpty())
                 pas << " := " << at->getInitialValue();
             pas << ";" << m_endl;
         }
         pas << m_endl;
     }
-    if (info.atpriv.count()) {
+
+    UMLAttributeList atpriv = c->getAttributeList(Uml::Visibility::Private);
+    if (atpriv.count()) {
         pas << "private" << m_endl << m_endl;
-        UMLAttribute *at;
-        UMLAttributeList atpriv = info.atpriv;
-        for (at = atpriv.first(); at; at = atpriv.next()) {
+
+        foreach (UMLAttribute* at , atpriv ) {
             // if (at->getStatic())
             //     continue;
             pas << getIndent() << cleanName(at->getName()) << " : "
                 << at->getTypeName();
-            if (at && at->getInitialValue().latin1() && ! at->getInitialValue().isEmpty())
+            if (at && !at->getInitialValue().isEmpty())
                 pas << " := " << at->getInitialValue();
             pas << ";" << m_endl;
         }
@@ -342,7 +337,7 @@ void PascalWriter::writeOperation(UMLOperation *op, QTextStream &pas, bool is_co
         pas << "(" << m_endl;
         uint i = 0;
         m_indentLevel++;
-        for (UMLAttribute *at = atl.first(); at; at = atl.next()) {
+        foreach (UMLAttribute *at , atl ) {
             pas << getIndent();
             if (is_comment)
                 pas << "// ";
@@ -360,10 +355,22 @@ void PascalWriter::writeOperation(UMLOperation *op, QTextStream &pas, bool is_co
         pas << ")";
     }
     if (! use_procedure)
-        pas << " : " << rettype;
-    pas << "; virtual; abstract;" << m_endl << m_endl;
-    // TBH, we make the methods abstract here because we don't have the means
-    // for generating meaningful implementations.
+        pas << " : " << rettype << ";";
+
+    QString sourceCode = op->getSourceCode();
+    if (sourceCode.isEmpty()) {
+        pas << " virtual; abstract;" << m_endl << m_endl;
+        // TBH, we make the methods abstract here because we don't have the means
+        // for generating meaningful implementations.
+    }
+    else {
+        pas << m_endl;
+        pas << getIndent() << "begin" << m_endl;
+        m_indentLevel++;
+        pas << formatSourceCode(sourceCode, getIndent());
+        m_indentLevel--;
+        pas << getIndent() << "end;" << m_endl << m_endl;
+    }
 }
 
 QStringList PascalWriter::defaultDatatypes() {
@@ -406,7 +413,7 @@ bool PascalWriter::isReservedKeyword(const QString & rPossiblyReservedKeyword) {
 
     QStringList::ConstIterator it;
     for (it = keywords.begin(); it != keywords.end(); ++it)
-        if ((*it).lower() == rPossiblyReservedKeyword.lower())
+        if ((*it).toLower() == rPossiblyReservedKeyword.toLower())
             return true;
 
     return false;
