@@ -13,7 +13,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2007                                               *
+ *   copyright (C) 2006-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -64,9 +64,8 @@ void RubyCodeDocumentation::saveToXMI ( QDomDocument & doc, QDomElement & root )
 /**
  * @return    QString
  */
-QString RubyCodeDocumentation::toString ( )
+QString RubyCodeDocumentation::toString ( ) const
 {
-
     QString output = "";
 
     // simple output method
