@@ -1,6 +1,6 @@
 /***************************************************************************
     copyright            : (C) 2003 Brian Thomas brian.thomas@gsfc.nasa.gov
-      (C) 2004-2006  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
+      (C) 2004-2007  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>
 ***************************************************************************/
 
 /***************************************************************************
@@ -53,7 +53,7 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
 {
 
     if (!c) {
-        kDebug()<<"Cannot write class of NULL classifier!\n";
+        uDebug()<<"Cannot write class of NULL classifier!\n";
         return;
     }
 
@@ -88,7 +88,7 @@ void XMLSchemaWriter::writeClass(UMLClassifier *c)
     QString headerText = getHeadingFile(".xsd");
     if(!headerText.isEmpty()) {
         headerText.replace(QRegExp("%filename%"),fileName);
-        headerText.replace(QRegExp("%filepath%"),file.name());
+        headerText.replace(QRegExp("%filepath%"),file.fileName());
     }
     if(!headerText.isEmpty())
         XMLschema<<headerText<<m_endl;
@@ -177,11 +177,10 @@ UMLAttributeList XMLSchemaWriter::findAttributes (UMLClassifier *c)
 {
     // sort attributes by Scope
     UMLAttributeList attribs;
-    attribs.setAutoDelete(false);
 
     if (!c->isInterface()) {
         UMLAttributeList atl = c->getAttributeList();
-        for(UMLAttribute *at=atl.first(); at ; at=atl.next()) {
+        foreach(UMLAttribute *at ,  atl ) {
             switch(at->getVisibility())
             {
               case Uml::Visibility::Public:
@@ -233,12 +232,12 @@ void XMLSchemaWriter::writeAbstractClassifier (UMLClassifier *c, QTextStream &XM
         writeAttributeGroupDecl(elementName, attribs, XMLschema);
 
         // now write out inheriting classes, as needed
-        for(UMLClassifier * classifier = subclasses.first(); classifier; classifier = subclasses.next())
+        foreach (UMLClassifier * classifier , subclasses )
             writeClassifier(classifier, XMLschema);
     }
 
     // write out any superclasses as needed
-    for(UMLClassifier *classifier = superclasses.first(); classifier; classifier = superclasses.next())
+    foreach (UMLClassifier *classifier , superclasses )
         writeClassifier(classifier, XMLschema);
 
 }
@@ -258,7 +257,7 @@ void XMLSchemaWriter::writeGroupClassifierDecl (UMLClassifier *c,
     XMLschema<<getIndent()<<"<"<<makeSchemaTag("choice")<<">"<<m_endl;
     m_indentLevel++;
 
-    for(UMLClassifier *classifier = subclasses.first(); classifier; classifier = subclasses.next()) {
+    foreach(UMLClassifier *classifier , subclasses ) {
         writeAssociationRoleDecl(classifier, "1", XMLschema);
     }
 
@@ -343,7 +342,7 @@ void XMLSchemaWriter::writeComplexTypeClassifierDecl (UMLClassifier *c,
         if(hasAttributes)
         {
             writeAttributeDecls(attribs, XMLschema);
-            for(uint i= 0; i < attribGroups.count(); i++)
+            for (int i= 0; i < attribGroups.count(); i++)
                 XMLschema<<getIndent()<<"<"<<makeSchemaTag("attributeGroup")<<" ref=\""
                 <<makePackageTag(attribGroups[i])<<"\"/>"<<m_endl;
         }
@@ -391,11 +390,11 @@ void XMLSchemaWriter::writeConcreteClassifier (UMLClassifier *c, QTextStream &XM
     writeChildObjsInAssociation(c, compositions, XMLschema);
 
     // write out any superclasses as needed
-    for(UMLClassifier *classifier = superclasses.first(); classifier; classifier = superclasses.next())
+    foreach(UMLClassifier *classifier , superclasses)
         writeClassifier(classifier, XMLschema);
 
     // write out any subclasses as needed
-    for(UMLClassifier *classifier = subclasses.first(); classifier; classifier = subclasses.next())
+    foreach(UMLClassifier *classifier , subclasses )
         writeClassifier(classifier, XMLschema);
 }
 
@@ -406,7 +405,7 @@ QStringList XMLSchemaWriter::findAttributeGroups (UMLClassifier *c)
     // have attributes, then we need to notice
     QStringList list;
     UMLClassifierList superclasses = c->findSuperClassConcepts(); // list of what inherits from us
-    for(UMLClassifier *classifier = superclasses.first(); classifier; classifier = superclasses.next())
+    foreach (UMLClassifier *classifier , superclasses )
     {
         if(classifier->getAbstract())
         {
@@ -436,8 +435,7 @@ void XMLSchemaWriter::writeChildObjsInAssociation (UMLClassifier *c,
 {
 
     UMLObjectList list = findChildObjsInAssociations (c, assoc);
-    for(UMLObject * obj = list.first(); obj; obj = list.next())
-    {
+    foreach(UMLObject* obj, list ) {
         UMLClassifier * thisClassifier = dynamic_cast<UMLClassifier*>(obj);
         if(thisClassifier)
             writeClassifier(thisClassifier, XMLschema);
@@ -458,9 +456,7 @@ void XMLSchemaWriter::markAsWritten(UMLClassifier *c) {
 void XMLSchemaWriter::writeAttributeDecls(UMLAttributeList &attribs, QTextStream &XMLschema )
 {
 
-    UMLAttribute *at;
-    for(at=attribs.first(); at; at=attribs.next())
-    {
+    foreach ( UMLAttribute* at , attribs ) {
         writeAttributeDecl(at,XMLschema);
     }
 
@@ -510,7 +506,7 @@ void XMLSchemaWriter::writeAttributeGroupDecl (const QString &elementName, UMLAt
 
         m_indentLevel++;
 
-        for( UMLAttribute *at=attribs.first(); at; at=attribs.next())
+        foreach( UMLAttribute *at , attribs )
         {
             writeAttributeDecl(at,XMLschema);
         }
@@ -531,8 +527,8 @@ void XMLSchemaWriter::writeComment( const QString &comment, QTextStream &XMLsche
     XMLschema<<indent<<"<!-- ";
     if (comment.contains(QRegExp("\n"))) {
         XMLschema<<m_endl;
-        QStringList lines = QStringList::split( "\n", comment);
-        for(uint i= 0; i < lines.count(); i++)
+        QStringList lines = comment.split( "\n" );
+        for (int i= 0; i < lines.count(); i++)
             XMLschema<<indent<<"     "<<lines[i]<<m_endl;
 
         XMLschema<<indent<<"-->"<<m_endl;
@@ -557,7 +553,7 @@ bool XMLSchemaWriter::writeAssociationDecls(UMLAssociationList associations,
     {
         bool printRoleA = false, printRoleB = false;
 
-        for(UMLAssociation *a = associations.first(); a; a = associations.next())
+        foreach (UMLAssociation *a , associations )
         {
             // it may seem counter intuitive, but you want to insert the role of the
             // *other* class into *this* class.
@@ -620,7 +616,7 @@ UMLObjectList XMLSchemaWriter::findChildObjsInAssociations (UMLClassifier *c, UM
 {
     Uml::IDType id = c->getID();
     UMLObjectList list;
-    for(UMLAssociation *a = associations.first(); a; a = associations.next())
+    foreach (UMLAssociation *a , associations )
     {
         if (a->getObjectId(Uml::A) == id
                 && a->getVisibility(Uml::B) != Uml::Visibility::Private
@@ -664,7 +660,7 @@ void XMLSchemaWriter::writeAssociationRoleDecl( UMLClassifier *c, const QString
     }
     else
     {
-        QStringList values = QStringList::split( QRegExp("[^\\d{1,}|\\*]"), multi);
+        QStringList values = multi.split( QRegExp("[^\\d{1,}|\\*]") );
 
         // could use some improvement here.. for sequences like "0..1,3..5,10" we
         // don't capture the whole "richness" of the multi. Instead we translate it
@@ -745,9 +741,9 @@ QString XMLSchemaWriter::fixInitialStringDeclValue(QString value, const QString
 {
     // check for strings only
     if (!value.isEmpty() && type == "xs:string") {
-        if (!value.startsWith("\""))
+        if (!value.startsWith('"'))
             value.remove(0,1);
-        if (!value.endsWith("\""))
+        if (!value.endsWith('"'))
             value.remove(value.length(),1);
     }
     return value;
