@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2007                                               *
+ *   copyright (C) 2005-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -14,7 +14,7 @@
 
 #include <stdio.h>
 // qt/kde includes
-#include <qregexp.h>
+#include <QtCore/QRegExp>
 #include <kdebug.h>
 // app includes
 #include "import_utils.h"
@@ -28,14 +28,17 @@
 #include "../attribute.h"
 #include "../association.h"
 
-AdaImport::AdaImport() : NativeImportBase("--") {
+AdaImport::AdaImport() : NativeImportBase("--")
+{
    initVars();
 }
 
-AdaImport::~AdaImport() {
+AdaImport::~AdaImport()
+{
 }
 
-void AdaImport::initVars() {
+void AdaImport::initVars()
+{
     m_inGenericFormalPart = false;
     m_classesDefinedInThisScope.clear();
     m_renaming.clear();
@@ -43,12 +46,13 @@ void AdaImport::initVars() {
 
 /// Split the line so that a string is returned as a single element of the list,
 /// when not in a string then split at white space.
-QStringList AdaImport::split(const QString& lin) {
+QStringList AdaImport::split(const QString& lin)
+{
     QStringList list;
     QString listElement;
     bool inString = false;
     bool seenSpace = false;
-    QString line = lin.stripWhiteSpace();
+    QString line = lin.trimmed();
     uint len = line.length();
     for (uint i = 0; i < len; i++) {
         const QChar& c = line[i];
@@ -77,7 +81,7 @@ QStringList AdaImport::split(const QString& lin) {
                 listElement = line.mid(i, 3);
                 i += 2;
                 list.append(listElement);
-                listElement = QString();
+                listElement.clear();
                 continue;
             }
             listElement += c;
@@ -88,7 +92,7 @@ QStringList AdaImport::split(const QString& lin) {
             seenSpace = true;
             if (!listElement.isEmpty()) {
                 list.append(listElement);
-                listElement = QString();
+                listElement.clear();
             }
         } else {
             listElement += c;
@@ -100,7 +104,8 @@ QStringList AdaImport::split(const QString& lin) {
     return list;
 }
 
-void AdaImport::fillSource(const QString& word) {
+void AdaImport::fillSource(const QString& word)
+{
     QString lexeme;
     const uint len = word.length();
     for (uint i = 0; i < len; i++) {
@@ -110,7 +115,7 @@ void AdaImport::fillSource(const QString& word) {
         } else {
             if (!lexeme.isEmpty()) {
                 m_source.append(lexeme);
-                lexeme = QString();
+                lexeme.clear();
             }
             if (c == ':' && word[i + 1] == '=') {
                 m_source.append(":=");
@@ -124,10 +129,11 @@ void AdaImport::fillSource(const QString& word) {
         m_source.append(lexeme);
 }
 
-QString AdaImport::expand(const QString& name) {
+QString AdaImport::expand(const QString& name)
+{
     QRegExp pfxRegExp("^(\\w+)\\.");
-    pfxRegExp.setCaseSensitive(false);
-    int pos = pfxRegExp.search(name);
+    pfxRegExp.setCaseSensitivity(Qt::CaseInsensitive);
+    int pos = pfxRegExp.indexIn(name);
     if (pos == -1)
         return name;
     QString result = name;
@@ -139,11 +145,12 @@ QString AdaImport::expand(const QString& name) {
     return result;
 }
 
-void AdaImport::parseStems(const QStringList& stems) {
+void AdaImport::parseStems(const QStringList& stems)
+{
     if (stems.isEmpty())
         return;
     QString base = stems.first();
-    uint i = 0;
+    int i = 0;
     while (1) {
         QString filename = base + ".ads";
         if (! m_parsedFiles.contains(filename)) {
@@ -165,18 +172,19 @@ void AdaImport::parseStems(const QStringList& stems) {
     }
 }
 
-bool AdaImport::parseStmt() {
-    const uint srcLength = m_source.count();
+bool AdaImport::parseStmt()
+{
+    const int srcLength = m_source.count();
     QString keyword = m_source[m_srcIndex];
     UMLDoc *umldoc = UMLApp::app()->getDocument();
-    //kDebug() << '"' << keyword << '"' << endl;
+    //uDebug() << '"' << keyword << '"';
     if (keyword == "with") {
         if (m_inGenericFormalPart) {
             // mapping of generic formal subprograms or packages is not yet implemented
             return false;
         }
         while (++m_srcIndex < srcLength && m_source[m_srcIndex] != ";") {
-            QStringList components = QStringList::split(".", m_source[m_srcIndex].lower());
+            QStringList components = m_source[m_srcIndex].toLower().split(".");
             const QString& prefix = components.first();
             if (prefix == "system" || prefix == "ada" || prefix == "gnat" ||
                 prefix == "interfaces" || prefix == "text_io" ||
@@ -198,7 +206,7 @@ bool AdaImport::parseStmt() {
     }
     if (keyword == "package") {
         const QString& name = advance();
-        QStringList parentPkgs = QStringList::split(".", name.lower());
+        QStringList parentPkgs = name.toLower().split(".");
         parentPkgs.pop_back();  // exclude the current package
         parseStems(parentPkgs);
         UMLObject *ns = NULL;
@@ -225,7 +233,7 @@ bool AdaImport::parseStmt() {
         } else if (m_source[m_srcIndex] == "renames") {
             m_renaming[name] = advance();
         } else {
-            kError() << "AdaImport::parseStmt: unexpected: " << m_source[m_srcIndex] << endl;
+            uError() << "unexpected: " << m_source[m_srcIndex];
             skipStmt("is");
         }
         if (m_inGenericFormalPart) {
@@ -240,7 +248,7 @@ bool AdaImport::parseStmt() {
         QString name = advance();
         advance();  // "is"
         QString base = expand(advance());
-        base.remove("Standard.", false);
+        base.remove("Standard.", Qt::CaseInsensitive);
         UMLObject *type = umldoc->findUMLObject(base, Uml::ot_UMLObject, m_scope[m_scopeIndex]);
         if (type == NULL) {
             type = Import_Utils::createUMLObject(Uml::ot_Datatype, base, m_scope[m_scopeIndex]);
@@ -260,8 +268,7 @@ bool AdaImport::parseStmt() {
         QString name = advance();
         QString next = advance();
         if (next == "(") {
-            kDebug() << "AdaImport::parseStmt(" << name << "): "
-                << "discriminant handling is not yet implemented" << endl;
+            uDebug() << name << ": discriminant handling is not yet implemented";
             // @todo Find out how to map discriminated record to UML.
             //       For now, we just create a pro forma empty record.
             Import_Utils::createUMLObject(Uml::ot_Class, name, m_scope[m_scopeIndex],
@@ -279,7 +286,7 @@ bool AdaImport::parseStmt() {
             return true;
         }
         if (next != "is") {
-            kError() << "AdaImport::parseStmt: expecting \"is\"" << endl;
+            uError() << "expecting \"is\"";
             return false;
         }
         next = advance();
@@ -354,7 +361,7 @@ bool AdaImport::parseStmt() {
             if (isExtension || m_isAbstract) {
                 t = Uml::ot_Class;
             } else {
-                base.remove("Standard.", false);
+                base.remove("Standard.", Qt::CaseInsensitive);
                 UMLObject *known = umldoc->findUMLObject(base, Uml::ot_UMLObject, m_scope[m_scopeIndex]);
                 t = (known ? known->getBaseType() : Uml::ot_Datatype);
             }
@@ -394,21 +401,21 @@ bool AdaImport::parseStmt() {
     if (keyword == "end") {
         if (m_klass) {
             if (advance() != "record") {
-                kError() << "end: expecting \"record\" at "
-                          << m_source[m_srcIndex] << endl;
+                uError() << "end: expecting \"record\" at "
+                          << m_source[m_srcIndex];
             }
             m_klass = NULL;
         } else if (m_scopeIndex) {
             if (advance() != ";") {
                 QString scopeName = m_scope[m_scopeIndex]->getFullyQualifiedName();
-                if (scopeName.lower() != m_source[m_srcIndex].lower())
-                    kError() << "end: expecting " << scopeName << ", found "
-                              << m_source[m_srcIndex] << endl;
+                if (scopeName.toLower() != m_source[m_srcIndex].toLower())
+                    uError() << "end: expecting " << scopeName << ", found "
+                              << m_source[m_srcIndex];
             }
             m_scopeIndex--;
             m_currentAccess = Uml::Visibility::Public;   // @todo make a stack for this
         } else {
-            kError() << "importAda: too many \"end\"" << endl;
+            uError() << "importAda: too many \"end\"";
         }
         skipStmt();
         return true;
@@ -426,7 +433,7 @@ bool AdaImport::parseStmt() {
             // subprograms.
             // In order to map those, we would need to create a UML
             // class with stereotype <<utility>> for the Ada package.
-            kDebug() << "ignoring parameterless " << keyword << " " << name << endl;
+            uDebug() << "ignoring parameterless " << keyword << " " << name;
             skipStmt();
             return true;
         }
@@ -438,13 +445,13 @@ bool AdaImport::parseStmt() {
             uint parNameCount = 0;
             do {
                 if (parNameCount >= MAX_PARNAMES) {
-                    kError() << "MAX_PARNAMES is exceeded at " << name << endl;
+                    uError() << "MAX_PARNAMES is exceeded at " << name;
                     break;
                 }
                 parName[parNameCount++] = advance();
             } while (advance() == ",");
             if (m_source[m_srcIndex] != ":") {
-                kError() << "importAda: expecting ':'" << endl;
+                uError() << "importAda: expecting ':'";
                 skipStmt();
                 break;
             }
@@ -470,7 +477,7 @@ bool AdaImport::parseStmt() {
             } else {
                 typeName = direction;  // In Ada, the default direction is "in"
             }
-            typeName.remove("Standard.", false);
+            typeName.remove("Standard.", Qt::CaseInsensitive);
             typeName = expand(typeName);
             if (op == NULL) {
                 // In Ada, the first parameter indicates the class.
@@ -502,12 +509,12 @@ bool AdaImport::parseStmt() {
         if (keyword == "function") {
             if (advance() != "return") {
                 if (klass)
-                    kError() << "importAda: expecting \"return\" at function "
-                        << name << endl;
+                    uError() << "importAda: expecting \"return\" at function "
+                        << name;
                 return false;
             }
             returnType = expand(advance());
-            returnType.remove("Standard.", false);
+            returnType.remove("Standard.", Qt::CaseInsensitive);
         }
         bool isAbstract = false;
         if (advance() == "is" && advance() == "abstract")
@@ -547,8 +554,8 @@ bool AdaImport::parseStmt() {
             if (advance() == "record")
                 skipStmt("end");
         } else {
-            kError() << "importAda: expecting \"use\" at rep spec of "
-                      << typeName << endl;
+            uError() << "importAda: expecting \"use\" at rep spec of "
+                      << typeName;
         }
         skipStmt();
         return true;
@@ -560,8 +567,8 @@ bool AdaImport::parseStmt() {
     }
     const QString& name = keyword;
     if (advance() != ":") {
-        kError() << "adaImport: expecting \":\" at " << name << " "
-                  << m_source[m_srcIndex] << endl;
+        uError() << "adaImport: expecting \":\" at " << name << " "
+                  << m_source[m_srcIndex];
         skipStmt();
         return true;
     }
