@@ -16,6 +16,8 @@
 #include <qfileinfo.h>
 #include <qdir.h>
 #include <qregexp.h>
+//Added by qt3to4:
+#include <Q3PtrList>
 #include <kdebug.h>
 // app includes
 #include "ast_utils.h"
@@ -69,13 +71,13 @@ void CppTree2Uml::parseNamespace( NamespaceAST* ast )
         QFileInfo fileInfo( m_fileName );
         QString shortFileName = fileInfo.baseName();
 
-        nsName.sprintf( "(%s_%d)", shortFileName.local8Bit().data(), m_anon++ );
+        nsName.sprintf( "(%s_%d)", shortFileName.toLocal8Bit().constData(), m_anon++ );
     } else {
         nsName = ast->namespaceName()->text();
     }
 
 #ifdef DEBUG_CPPTREE2UML
-    kDebug() << "CppTree2Uml::parseNamespace: " << nsName << endl;
+    kDebug() << "CppTree2Uml::parseNamespace: " << nsName;
 #endif
     UMLObject * o = Import_Utils::createUMLObject( Uml::ot_Package, nsName,
                                                  m_currentNamespace[m_nsCnt],
@@ -83,7 +85,7 @@ void CppTree2Uml::parseNamespace( NamespaceAST* ast )
     UMLPackage *ns = (UMLPackage *)o;
     m_currentScope.push_back( nsName );
     if (++m_nsCnt > STACKSIZE) {
-        kdError() << "CppTree2Uml::parseNamespace: excessive namespace nesting" << endl;
+        kError() << "CppTree2Uml::parseNamespace: excessive namespace nesting" << endl;
         m_nsCnt = STACKSIZE;
     }
     m_currentNamespace[m_nsCnt] = ns;
@@ -100,7 +102,7 @@ void CppTree2Uml::parseTypedef( TypedefAST* ast )
     DeclaratorAST* oldDeclarator = m_currentDeclarator;
 
     if( ast && ast->initDeclaratorList() && ast->initDeclaratorList()->initDeclaratorList().count() > 0 ) {
-            QPtrList<InitDeclaratorAST> lst( ast->initDeclaratorList()->initDeclaratorList() );
+            Q3PtrList<InitDeclaratorAST> lst( ast->initDeclaratorList()->initDeclaratorList() );
             m_currentDeclarator = lst.at( 0 )->declarator();
     }
 
@@ -120,8 +122,8 @@ void CppTree2Uml::parseTypedef( TypedefAST* ast )
         if( typeSpec->name() )
             typeId = typeSpec->name()->text();
 
-        QPtrList<InitDeclaratorAST> l( declarators->initDeclaratorList() );
-        QPtrListIterator<InitDeclaratorAST> it( l );
+        Q3PtrList<InitDeclaratorAST> l( declarators->initDeclaratorList() );
+        Q3PtrListIterator<InitDeclaratorAST> it( l );
 
         InitDeclaratorAST* initDecl = 0;
         while( 0 != (initDecl = it.current()) ){
@@ -139,7 +141,7 @@ void CppTree2Uml::parseTypedef( TypedefAST* ast )
                   id = d->declaratorId()->text();
             }
 //#ifdef DEBUG_CPPTREE2UML
-            kDebug() << "CppTree2Uml::parseTypedef: name=" << id << ", type=" << type << endl;
+            kDebug() << "CppTree2Uml::parseTypedef: name=" << id << ", type=" << type;
 //#endif
             /* @todo Trace typedefs back to their root type for deciding
                      whether to build a Datatype (for pointers.)  */
@@ -178,8 +180,8 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
     TemplateParameterListAST* parmListAST = ast->templateParameterList();
     if (parmListAST == NULL)
         return;
-    QPtrList<TemplateParameterAST> parmList = parmListAST->templateParameterList();
-    for (QPtrListIterator<TemplateParameterAST> it(parmList); it.current(); ++it) {
+    Q3PtrList<TemplateParameterAST> parmList = parmListAST->templateParameterList();
+    for (Q3PtrListIterator<TemplateParameterAST> it(parmList); it.current(); ++it) {
         // The template is either a typeParameter or a typeValueParameter.
 
         TemplateParameterAST* tmplParmNode = it.current();
@@ -191,7 +193,7 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
                 Model_Utils::NameAndType nt(typeName, NULL);
                 m_templateParams.append(nt);
             } else {
-                kdError() << "CppTree2Uml::parseTemplateDeclaration(type):"
+                kError() << "CppTree2Uml::parseTemplateDeclaration(type):"
                           << " nameNode is NULL" << endl;
             }
         }
@@ -200,7 +202,7 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
         if (valueNode) {
             TypeSpecifierAST* typeSpec = valueNode->typeSpec();
             if (typeSpec == NULL) {
-                kdError() << "CppTree2Uml::parseTemplateDeclaration(value):"
+                kError() << "CppTree2Uml::parseTemplateDeclaration(value):"
                           << " typeSpec is NULL" << endl;
                 continue;
             }
@@ -210,7 +212,7 @@ void CppTree2Uml::parseTemplateDeclaration( TemplateDeclarationAST* ast )
             DeclaratorAST* declNode = valueNode->declarator();
             NameAST* nameNode = declNode->declaratorId();
             if (nameNode == NULL) {
-                kdError() << "CppTree2Uml::parseTemplateDeclaration(value):"
+                kError() << "CppTree2Uml::parseTemplateDeclaration(value):"
                           << " nameNode is NULL" << endl;
                 continue;
             }
@@ -235,9 +237,9 @@ void CppTree2Uml::parseSimpleDeclaration( SimpleDeclarationAST* ast )
         parseTypeSpecifier( typeSpec );
 
     if( declarators ){
-        QPtrList<InitDeclaratorAST> l = declarators->initDeclaratorList();
+        Q3PtrList<InitDeclaratorAST> l = declarators->initDeclaratorList();
 
-        QPtrListIterator<InitDeclaratorAST> it( l );
+        Q3PtrListIterator<InitDeclaratorAST> it( l );
         while( it.current() ){
             parseDeclaration(  ast->functionSpecifier(), ast->storageSpecifier(), typeSpec, it.current() );
             ++it;
@@ -266,8 +268,8 @@ void CppTree2Uml::parseFunctionDefinition( FunctionDefinitionAST* ast )
     bool isConstructor = false;
 
     if( funSpec ){
-        QPtrList<AST> l = funSpec->nodeList();
-        QPtrListIterator<AST> it( l );
+        Q3PtrList<AST> l = funSpec->nodeList();
+        Q3PtrListIterator<AST> it( l );
         while( it.current() ){
             QString text = it.current()->text();
             if( text == "virtual" ) isVirtual = true;
@@ -277,8 +279,8 @@ void CppTree2Uml::parseFunctionDefinition( FunctionDefinitionAST* ast )
     }
 
     if( storageSpec ){
-        QPtrList<AST> l = storageSpec->nodeList();
-        QPtrListIterator<AST> it( l );
+        Q3PtrList<AST> l = storageSpec->nodeList();
+        Q3PtrListIterator<AST> it( l );
         while( it.current() ){
             QString text = it.current()->text();
             if( text == "friend" ) isFriend = true;
@@ -287,7 +289,7 @@ void CppTree2Uml::parseFunctionDefinition( FunctionDefinitionAST* ast )
         }
     }
 
-    QString id = d->declaratorId()->unqualifiedName()->text().stripWhiteSpace();
+    QString id = d->declaratorId()->unqualifiedName()->text().trimmed();
 
     UMLClassifier *c = m_currentClass[m_clsCnt];
     if (c == NULL) {
@@ -300,7 +302,7 @@ void CppTree2Uml::parseFunctionDefinition( FunctionDefinitionAST* ast )
     UMLOperation *m = Import_Utils::makeOperation(c, id);
     // if a class has no return type, it could be a constructor or
     // a destructor
-    if (d && returnType.isEmpty() && id.find("~") == -1)
+    if (d && returnType.isEmpty() && id.indexOf('~') == -1)
         isConstructor = true;
 
     parseFunctionArguments( d, m );
@@ -330,19 +332,19 @@ void CppTree2Uml::parseClassSpecifier( ClassSpecifierAST* ast )
 
     QString className;
     if( !ast->name() && m_currentDeclarator && m_currentDeclarator->declaratorId() ) {
-        className = m_currentDeclarator->declaratorId()->text().stripWhiteSpace();
+        className = m_currentDeclarator->declaratorId()->text().trimmed();
     } else if( !ast->name() ){
         QFileInfo fileInfo( m_fileName );
         QString shortFileName = fileInfo.baseName();
-        className.sprintf( "(%s_%d)", shortFileName.local8Bit().data(), m_anon++ );
+        className.sprintf( "(%s_%d)", shortFileName.toLocal8Bit().constData(), m_anon++ );
     } else {
-        className = ast->name()->unqualifiedName()->text().stripWhiteSpace();
+        className = ast->name()->unqualifiedName()->text().trimmed();
     }
 //#ifdef DEBUG_CPPTREE2UML
-    kDebug() << "CppTree2Uml::parseClassSpecifier: name=" << className << endl;
+    kDebug() << "CppTree2Uml::parseClassSpecifier: name=" << className;
 //#endif
     if( !scopeOfName( ast->name(), QStringList() ).isEmpty() ){
-        kDebug() << "skip private class declarations" << endl;
+        kDebug() << "skip private class declarations";
         return;
     }
 
@@ -360,12 +362,12 @@ void CppTree2Uml::parseClassSpecifier( ClassSpecifierAST* ast )
 
     m_currentScope.push_back( className );
     if (++m_clsCnt > STACKSIZE) {
-        kdError() << "CppTree2Uml::parseNamespace: excessive class nesting" << endl;
+        kError() << "CppTree2Uml::parseNamespace: excessive class nesting" << endl;
         m_clsCnt = STACKSIZE;
     }
     m_currentClass[m_clsCnt] = klass;
     if (++m_nsCnt > STACKSIZE) {
-        kdError() << "CppTree2Uml::parseNamespace: excessive namespace nesting" << endl;
+        kError() << "CppTree2Uml::parseNamespace: excessive namespace nesting" << endl;
         m_nsCnt = STACKSIZE;
     }
     m_currentNamespace[m_nsCnt] = (UMLPackage*)klass;
@@ -387,15 +389,15 @@ void CppTree2Uml::parseEnumSpecifier( EnumSpecifierAST* ast )
     NameAST *nameNode = ast->name();
     if (nameNode == NULL)
         return;  // skip constants
-    QString typeName = nameNode->unqualifiedName()->text().stripWhiteSpace();
+    QString typeName = nameNode->unqualifiedName()->text().trimmed();
     if (typeName.isEmpty())
         return;  // skip constants
     UMLObject *o = Import_Utils::createUMLObject( Uml::ot_Enum, typeName,
                                                 m_currentNamespace[m_nsCnt],
                                                 ast->comment() );
 
-    QPtrList<EnumeratorAST> l = ast->enumeratorList();
-    QPtrListIterator<EnumeratorAST> it( l );
+    Q3PtrList<EnumeratorAST> l = ast->enumeratorList();
+    Q3PtrListIterator<EnumeratorAST> it( l );
     while ( it.current() ) {
         QString enumLiteral = it.current()->id()->text();
         Import_Utils::addEnumLiteral( (UMLEnum*)o, enumLiteral );
@@ -410,7 +412,7 @@ void CppTree2Uml::parseElaboratedTypeSpecifier( ElaboratedTypeSpecifierAST* type
     ///              - Using typeSpec->text() is probably not good, decode
     ///                the kind() instead.
     QString text = typeSpec->text();
-    kDebug() << "CppTree2Uml::parseElaboratedTypeSpecifier: text is " << text << endl;
+    kDebug() << "CppTree2Uml::parseElaboratedTypeSpecifier: text is " << text;
     text.remove(QRegExp("^class\\s+"));
     UMLObject *o = Import_Utils::createUMLObject(Uml::ot_Class, text, m_currentNamespace[m_nsCnt]);
     flushTemplateParams( static_cast<UMLClassifier*>(o) );
@@ -457,8 +459,8 @@ void CppTree2Uml::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
     //bool isInitialized = decl->initializer() != 0;
 
     if( storageSpec ){
-        QPtrList<AST> l = storageSpec->nodeList();
-        QPtrListIterator<AST> it( l );
+        Q3PtrList<AST> l = storageSpec->nodeList();
+        Q3PtrListIterator<AST> it( l );
         while( it.current() ){
             QString text = it.current()->text();
             if( text == "friend" ) isFriend = true;
@@ -474,7 +476,7 @@ void CppTree2Uml::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
 
 void CppTree2Uml::parseAccessDeclaration( AccessDeclarationAST * access )
 {
-    QPtrList<AST> l = access->accessList();
+    Q3PtrList<AST> l = access->accessList();
 
     QString accessStr = l.at( 0 )->text();
 
@@ -495,8 +497,8 @@ void CppTree2Uml::parseFunctionDeclaration(  GroupAST* funSpec, GroupAST* storag
     bool isConstructor = false;
 
     if( funSpec ){
-        QPtrList<AST> l = funSpec->nodeList();
-        QPtrListIterator<AST> it( l );
+        Q3PtrList<AST> l = funSpec->nodeList();
+        Q3PtrListIterator<AST> it( l );
         while( it.current() ){
             QString text = it.current()->text();
             if( text == "virtual" ) isVirtual = true;
@@ -506,8 +508,8 @@ void CppTree2Uml::parseFunctionDeclaration(  GroupAST* funSpec, GroupAST* storag
     }
 
     if( storageSpec ){
-        QPtrList<AST> l = storageSpec->nodeList();
-        QPtrListIterator<AST> it( l );
+        Q3PtrList<AST> l = storageSpec->nodeList();
+        Q3PtrListIterator<AST> it( l );
         while( it.current() ){
             QString text = it.current()->text();
             if( text == "friend" ) isFriend = true;
@@ -528,9 +530,9 @@ void CppTree2Uml::parseFunctionDeclaration(  GroupAST* funSpec, GroupAST* storag
 
     QString returnType = typeOfDeclaration( typeSpec, d );
     UMLOperation *m = Import_Utils::makeOperation(c, id);
-    // if a class has no return type, it could be a constructor or
+    // if a class has no return type, it could de a constructor or
     // a destructor
-    if (d && returnType.isEmpty() && id.find("~") == -1)
+    if (d && returnType.isEmpty() && id.indexOf('~') == -1)
         isConstructor = true;
 
     parseFunctionArguments( d, m );
@@ -546,15 +548,15 @@ void CppTree2Uml::parseFunctionArguments(DeclaratorAST* declarator,
 
     if( clause && clause->parameterDeclarationList() ){
         ParameterDeclarationListAST* params = clause->parameterDeclarationList();
-        QPtrList<ParameterDeclarationAST> l( params->parameterList() );
-        QPtrListIterator<ParameterDeclarationAST> it( l );
+        Q3PtrList<ParameterDeclarationAST> l( params->parameterList() );
+        Q3PtrListIterator<ParameterDeclarationAST> it( l );
         while( it.current() ){
             ParameterDeclarationAST* param = it.current();
             ++it;
 
             QString name;
             if (param->declarator())
-                name = declaratorToString(param->declarator(), QString::null, true );
+                name = declaratorToString(param->declarator(), QString(), true );
 
             QString tp = typeOfDeclaration( param->typeSpec(), param->declarator() );
 
@@ -567,14 +569,14 @@ void CppTree2Uml::parseFunctionArguments(DeclaratorAST* declarator,
 QString CppTree2Uml::typeOfDeclaration( TypeSpecifierAST* typeSpec, DeclaratorAST* declarator )
 {
     if( !typeSpec || !declarator )
-        return QString::null;
+        return QString();
 
     QString text;
 
     text += typeSpec->text();
 
-    QPtrList<AST> ptrOpList = declarator->ptrOpList();
-    for( QPtrListIterator<AST> it(ptrOpList); it.current(); ++it ){
+    Q3PtrList<AST> ptrOpList = declarator->ptrOpList();
+    for( Q3PtrListIterator<AST> it(ptrOpList); it.current(); ++it ){
         text += it.current()->text();
     }
 
@@ -583,8 +585,8 @@ QString CppTree2Uml::typeOfDeclaration( TypeSpecifierAST* typeSpec, DeclaratorAS
 
 void CppTree2Uml::parseBaseClause( BaseClauseAST * baseClause, UMLClassifier* klass )
 {
-    QPtrList<BaseSpecifierAST> l = baseClause->baseSpecifierList();
-    QPtrListIterator<BaseSpecifierAST> it( l );
+    Q3PtrList<BaseSpecifierAST> l = baseClause->baseSpecifierList();
+    Q3PtrListIterator<BaseSpecifierAST> it( l );
     while( it.current() ){
         BaseSpecifierAST* baseSpecifier = it.current();
         ++it;
@@ -606,8 +608,8 @@ QStringList CppTree2Uml::scopeOfName( NameAST* id, const QStringList& startScope
     if( id && id->classOrNamespaceNameList().count() ){
         if( id->isGlobal() )
             scope.clear();
-        QPtrList<ClassOrNamespaceNameAST> l = id->classOrNamespaceNameList();
-        QPtrListIterator<ClassOrNamespaceNameAST> it( l );
+        Q3PtrList<ClassOrNamespaceNameAST> l = id->classOrNamespaceNameList();
+        Q3PtrListIterator<ClassOrNamespaceNameAST> it( l );
         while( it.current() ){
             if( it.current()->name() ){
                scope << it.current()->name()->text();
