@@ -45,14 +45,14 @@ void NativeImportBase::setMultiLineAltComment(const QString &intro, const QStrin
 }
 
 void NativeImportBase::skipStmt(QString until /* = ";" */) {
-    const uint srcLength = m_source.count();
+    const int srcLength = m_source.count();
     while (m_srcIndex < srcLength && m_source[m_srcIndex] != until)
         m_srcIndex++;
 }
 
 bool NativeImportBase::skipToClosing(QChar opener) {
     QString closing;
-    switch (opener) {
+    switch (opener.toLatin1()) {
         case '{':
             closing = "}";
             break;
@@ -66,13 +66,12 @@ bool NativeImportBase::skipToClosing(QChar opener) {
             closing = ">";
             break;
         default:
-            kError() << "NativeImportBase::skipToClosing(" << opener
-                << "): " << "illegal input character" << endl;
+            uError() << "opener='" << opener << "': illegal input character" << endl;
             return false;
     }
     const QString opening(opener);
     skipStmt(opening);
-    const uint srcLength = m_source.count();
+    const int srcLength = m_source.count();
     int nesting = 0;
     while (m_srcIndex < srcLength) {
         QString nextToken = advance();
@@ -113,12 +112,12 @@ bool NativeImportBase::preprocess(QString& line) {
     // Check for end of multi line comment.
     if (m_inComment) {
         int delimiterLen = 0;
-        int pos = line.find(m_multiLineCommentEnd);
+        int pos = line.indexOf(m_multiLineCommentEnd);
         if (pos == -1) {
             if (! m_multiLineAltCommentEnd.isEmpty())
-                pos = line.find(m_multiLineAltCommentEnd);
+                pos = line.indexOf(m_multiLineAltCommentEnd);
             if (pos == -1) {
-                m_comment += line + "\n";
+                m_comment += line + '\n';
                 return true;  // done
             }
             delimiterLen = m_multiLineAltCommentEnd.length();
@@ -127,7 +126,7 @@ bool NativeImportBase::preprocess(QString& line) {
         }
         if (pos > 0) {
             QString text = line.mid(0, pos - 1);
-            m_comment += text.stripWhiteSpace();
+            m_comment += text.trimmed();
         }
         m_source.append(m_singleLineCommentIntro + m_comment);  // denotes comments in `m_source'
         m_srcIndex++;
@@ -142,20 +141,20 @@ bool NativeImportBase::preprocess(QString& line) {
     // Check for start of multi line comment.
     int delimIntroLen = 0;
     int delimEndLen = 0;
-    int pos = line.find(m_multiLineCommentIntro);
+    int pos = line.indexOf(m_multiLineCommentIntro);
     if (pos != -1) {
         delimIntroLen = m_multiLineCommentIntro.length();
     } else if (!m_multiLineAltCommentIntro.isEmpty()) {
-        pos = line.find(m_multiLineAltCommentIntro);
+        pos = line.indexOf(m_multiLineAltCommentIntro);
         if (pos != -1)
             delimIntroLen = m_multiLineAltCommentIntro.length();
     }
     if (pos != -1) {
-        int endpos = line.find(m_multiLineCommentEnd);
+        int endpos = line.indexOf(m_multiLineCommentEnd);
         if (endpos != -1) {
             delimEndLen = m_multiLineCommentEnd.length();
         } else if (!m_multiLineAltCommentEnd.isEmpty()) {
-            endpos = line.find(m_multiLineAltCommentEnd);
+            endpos = line.indexOf(m_multiLineAltCommentEnd);
             if (endpos != -1)
                 delimEndLen = m_multiLineAltCommentEnd.length();
         }
@@ -163,7 +162,7 @@ bool NativeImportBase::preprocess(QString& line) {
             m_inComment = true;
             if (pos + delimIntroLen < (int)line.length()) {
                 QString cmnt = line.mid(pos + delimIntroLen);
-                m_comment += cmnt.stripWhiteSpace() + "\n";
+                m_comment += cmnt.trimmed() + '\n';
             }
             if (pos == 0)
                 return true;  // done
@@ -171,7 +170,7 @@ bool NativeImportBase::preprocess(QString& line) {
         } else {   // It's a multiline comment on a single line.
             if (endpos > pos + delimIntroLen)  {
                 QString cmnt = line.mid(pos + delimIntroLen, endpos - pos - delimIntroLen);
-                cmnt = cmnt.stripWhiteSpace();
+                cmnt = cmnt.trimmed();
                 if (!cmnt.isEmpty())
                     m_source.append(m_singleLineCommentIntro + cmnt);
             }
@@ -195,15 +194,15 @@ QStringList NativeImportBase::split(const QString& lin) {
     QString listElement;
     QChar stringIntro = 0;  // buffers the string introducer character
     bool seenSpace = false;
-    QString line = lin.stripWhiteSpace();
-    for (uint i = 0; i < line.length(); i++) {
+    QString line = lin.trimmed();
+    for (int i = 0; i < line.length(); i++) {
         const QChar& c = line[i];
-        if (stringIntro) {        // we are in a string
+        if (stringIntro.toLatin1()) {        // we are in a string
             listElement += c;
             if (c == stringIntro) {
                 if (line[i - 1] != '\\') {
                     list.append(listElement);
-                    listElement = QString();
+                    listElement.clear();
                     stringIntro = 0;  // we are no longer in a string
                 }
             }
@@ -219,7 +218,7 @@ QStringList NativeImportBase::split(const QString& lin) {
             seenSpace = true;
             if (!listElement.isEmpty()) {
                 list.append(listElement);
-                listElement = QString();
+                listElement.clear();
             }
         } else {
             listElement += c;
@@ -237,7 +236,7 @@ void NativeImportBase::scan(QString line) {
     if (preprocess(line))
         return;
     // Check for single line comment.
-    int pos = line.find(m_singleLineCommentIntro);
+    int pos = line.indexOf(m_singleLineCommentIntro);
     if (pos != -1) {
         QString cmnt = line.mid(pos);
         m_source.append(cmnt);
@@ -271,12 +270,12 @@ void NativeImportBase::parseFile(const QString& filename) {
     if (filename.contains('/')) {
         QString path = filename;
         path.remove( QRegExp("/[^/]+$") );
-        kDebug() << msgPrefix << "adding path " << path << endl;
+        uDebug() << msgPrefix << "adding path " << path;
         Import_Utils::addIncludePath(path);
     }
     if (! QFile::exists(filename)) {
-        if (filename.startsWith("/")) {
-            kError() << msgPrefix << "cannot find file" << endl;
+        if (filename.startsWith('/')) {
+            uError() << msgPrefix << "cannot find file" << endl;
             return;
         }
         bool found = false;
@@ -284,8 +283,8 @@ void NativeImportBase::parseFile(const QString& filename) {
         for (QStringList::Iterator pathIt = includePaths.begin();
                                    pathIt != includePaths.end(); ++pathIt) {
             QString path = (*pathIt);
-            if (! path.endsWith("/")) {
-                path.append("/");
+            if (! path.endsWith('/')) {
+                path.append('/');
             }
             if (QFile::exists(path + filename)) {
                 fname.prepend(path);
@@ -294,16 +293,16 @@ void NativeImportBase::parseFile(const QString& filename) {
             }
         }
         if (! found) {
-            kError() << msgPrefix << "cannot find file" << endl;
+            uError() << msgPrefix << "cannot find file" << endl;
             return;
         }
     }
     QFile file(fname);
-    if (! file.open(IO_ReadOnly)) {
-        kError() << msgPrefix << "cannot open file" << endl;
+    if (! file.open(QIODevice::ReadOnly)) {
+        uError() << msgPrefix << "cannot open file" << endl;
         return;
     }
-    kDebug() << msgPrefix << "parsing." << endl;
+    uDebug() << msgPrefix << "parsing.";
     // Scan the input file into the QStringList m_source.
     m_source.clear();
     m_srcIndex = 0;
@@ -319,19 +318,19 @@ void NativeImportBase::parseFile(const QString& filename) {
     m_currentAccess = Uml::Visibility::Public;
     m_scopeIndex = 0;
     m_scope[0] = NULL;  // index 0 is reserved for global scope
-    const uint srcLength = m_source.count();
+    const int srcLength = m_source.count();
     for (m_srcIndex = 0; m_srcIndex < srcLength; m_srcIndex++) {
         const QString& firstToken = m_source[m_srcIndex];
-        //kDebug() << '"' << firstToken << '"' << endl;
+        //uDebug() << '"' << firstToken << '"';
         if (firstToken.startsWith(m_singleLineCommentIntro)) {
             m_comment = firstToken.mid(m_singleLineCommentIntro.length());
             continue;
         }
         if (! parseStmt())
            skipStmt();
-        m_comment = QString();
+        m_comment.clear();
     }
-    kDebug() << msgPrefix << "end of parse." << endl;
+    uDebug() << msgPrefix << "end of parse.";
 }
 
 void NativeImportBase::initialize() {
