@@ -13,8 +13,8 @@
 #define ACTIVITYPAGE_H
 //qt includes
 #include <qwidget.h>
-#include <qgroupbox.h>
-#include <qlistbox.h>
+#include <q3groupbox.h>
+#include <q3listbox.h>
 //kde includes
 #include <karrowbutton.h>
 //app includes
@@ -53,7 +53,7 @@ protected:
     /**
      *  Set the state of the widgets on the page with the given value.
      *
-     *  @param  state   The state to set the widgets as.
+     *  @param state The state to set the widgets as.
      */
     void enableWidgets(bool state);
 
@@ -67,8 +67,8 @@ protected:
      */
     ListPopupMenu * m_pMenu;
     //GUI widgets
-    QListBox * m_pActivityLB;
-    QGroupBox * m_pActivityGB;
+    Q3ListBox * m_pActivityLB;
+    Q3GroupBox * m_pActivityGB;
     KArrowButton * m_pUpArrowB, * m_pDownArrowB, * m_pTopArrowB, *m_pBottomArrowB;
     QPushButton* m_pDeleteActivityButton;
     QPushButton* m_pRenameButton;
@@ -77,11 +77,12 @@ public slots:
     /**
      *  Popup menu item selected
      */
-    void slotMenuSelection( int sel );
-    void slotClicked( QListBoxItem* item );
-    void slotDoubleClicked( QListBoxItem* item );
-    void slotRightButtonClicked(QListBoxItem* item, const QPoint& p);
-    void slotRightButtonPressed(QListBoxItem* item, const QPoint& p);
+    void slotMenuSelection(QAction* action);
+    void slotClicked( Q3ListBoxItem* item );
+    void slotDoubleClicked( Q3ListBoxItem* item );
+    void slotRightButtonClicked(Q3ListBoxItem* item, const QPoint& p);
+    void slotRightButtonPressed(Q3ListBoxItem* item, const QPoint& p);
+
     void slotTopClicked();
     void slotUpClicked();
     void slotDownClicked();
