@@ -1,38 +1,35 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2006                                                *
- *  Umbrello UML Modeller Authors <uml-devel@ uml.sf.net>                  *
+ *  copyright (C) 2002-2008                                                *
+ *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
-
-
 #ifndef SETTINGSDLG_H
 #define SETTINGSDLG_H
-//qt includes
-#include <qgroupbox.h>
-#include <qcheckbox.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qradiobutton.h>
-#include <qbuttongroup.h>
-#include <qdict.h>
-//kde includes
+
+// qt includes
+#include <QtGui/QGroupBox>
+#include <QtGui/QCheckBox>
+#include <QtGui/QPushButton>
+#include <QtGui/QLabel>
+#include <QtGui/QRadioButton>
+
+// kde includes
 #include <kcombobox.h>
 #include <kfontdialog.h>
-#include <kdialogbase.h>
+#include <kpagedialog.h>
 #include <kcolorbutton.h>
 #include <knuminput.h>
-//app includes
+#include <klineedit.h>
 
-#include "../optionstate.h"
+// app includes
+#include "optionstate.h"
 
-class CodeGenerationOptionsPage;
+class CodeGenOptionsPage;
 class CodeViewerOptionsPage;
-class CodeGenerator;
 
 /**
  * @author Paul Hensgen
@@ -40,8 +37,8 @@ class CodeGenerator;
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
 
-class SettingsDlg : public KDialogBase {
-
+class SettingsDlg : public KPageDialog
+{
     Q_OBJECT
 
 public:
@@ -56,17 +53,8 @@ public:
     QString getCodeGenerationLanguage();
 
 protected:
-    /**
-    * Inserts @p type into the type-combobox as well as its completion object.
-    */
     void insertDiagram( const QString& type, int index = -1 );
-    /**
-    * Inserts @p type into the type-combobox as well as its completion object.
-    */
     void insertAttribScope( const QString& type, int index = -1 );
-    /**
-    * Inserts @p type into the type-combobox as well as its completion object.
-    */
     void insertOperationScope( const QString& type, int index = -1 );
 
 private:
@@ -97,24 +85,25 @@ private:
 
         KIntSpinBox * timeISB;
         KComboBox * diagramKB;
+        KComboBox * languageKB;
 
         QCheckBox * undoCB;
         QCheckBox * tabdiagramsCB;
         QCheckBox * newcodegenCB;
         QCheckBox * angularLinesCB;
+        QCheckBox * footerPrintingCB;
         QCheckBox * autosaveCB;
-        QCheckBox * logoCB;
-        QCheckBox * tipCB;
         QCheckBox * loadlastCB;
 
-        // 2004-05-17 Achim Spangler: Allow definition of Suffix for autosave
+        // Allow definition of Suffix for autosave
         // ( Default: ".xmi" )
-        QLineEdit * autosaveSuffixT;
+        KLineEdit * autosaveSuffixT;
         QLabel    * autosaveSuffixL;
         // End AutoSave Suffix
 
         QLabel * startL;
-        QLabel *  autosaveL;
+        QLabel * autosaveL;
+        QLabel * defaultLanguageL;
     }
     ;//end struct GeneralWidgets
 
@@ -134,8 +123,8 @@ private:
         QLabel * attributeLabel;
         QLabel * operationLabel;
 
-        KComboBox* m_pAttribScopeCB;
-        KComboBox* m_pOperationScopeCB;
+        KComboBox * m_pAttribScopeCB;
+        KComboBox * m_pOperationScopeCB;
 
     }
     ;//end struct ClassWidgets
@@ -151,7 +140,7 @@ private:
     void setupClassPage();
     void setupCodeGenPage();
     void setupCodeViewerPage(Settings::CodeViewerState options);
-    void applyPage( Settings::Page page );
+    void applyPage( KPageWidgetItem* );
 
     //private attributes
     FontWidgets m_FontWidgets;
@@ -159,15 +148,12 @@ private:
     UIWidgets m_UiWidgets;
     ClassWidgets m_ClassWidgets;
     Settings::OptionState *m_pOptionState;
-    CodeGenerationOptionsPage * m_pCodeGenPage;
+    CodeGenOptionsPage * m_pCodeGenPage;
     CodeViewerOptionsPage * m_pCodeViewerPage;
 
-    KConfig * m_pCfg;
     bool m_bChangesApplied;
+    KPageWidgetItem *pageCodeViewer, *pageFont, *pageCodeGen, *pageUserInterface, *pageGeneral, *pageClass;
 
-    //signals
-signals:
-    //slots
 private slots:
     void slotApply();
     void slotOk();
