@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2006-2007                                                *
+ *  copyright (C) 2006-2008                                                *
  *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
  ***************************************************************************/
 
@@ -13,9 +13,9 @@
 #include "object_factory.h"
 
 // qt/kde includes
-#include <qregexp.h>
-#include <qstringlist.h>
-#include <kapplication.h>
+#include <QtCore/QRegExp>
+#include <QtCore/QStringList>
+#include <QtGui/QApplication>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
@@ -37,33 +37,41 @@
 #include "node.h"
 #include "artifact.h"
 #include "stereotype.h"
+#include "category.h"
 #include "association.h"
 #include "umldoc.h"
 #include "uml.h"
+#include "uniqueconstraint.h"
+#include "foreignkeyconstraint.h"
+#include "checkconstraint.h"
 #include "codegenerator.h"
 #include "model_utils.h"
 #include "uniqueid.h"
+#include "cmds.h"
 
 namespace Object_Factory {
 
 Uml::IDType g_predefinedId = Uml::id_None;
 
-void assignUniqueIdOnCreation(bool yesno) {
+void assignUniqueIdOnCreation(bool yesno)
+{
     if (yesno)
         g_predefinedId = Uml::id_None;
     else
         g_predefinedId = Uml::id_Reserved;
 }
 
-bool assignUniqueIdOnCreation() {
+bool assignUniqueIdOnCreation()
+{
     return (g_predefinedId == Uml::id_None);
 }
 
 UMLObject* createNewUMLObject(Uml::Object_Type type, const QString &name,
-                              UMLPackage *parentPkg) {
+                              UMLPackage *parentPkg)
+{
     if (parentPkg == NULL) {
-        kError() << "Object_Factory::createNewUMLObject(" << name
-            << "): parentPkg is NULL" << endl;
+        uError() << "Object_Factory::createNewUMLObject(" << name
+            << "): parentPkg is NULL";
         return NULL;
     }
     UMLObject *o = NULL;
@@ -110,29 +118,35 @@ UMLObject* createNewUMLObject(Uml::Object_Type type, const QString &name,
         case Uml::ot_Folder:
             o = new UMLFolder(name, g_predefinedId);
             break;
+        case Uml::ot_Category:
+            o = new UMLCategory(name, g_predefinedId);
+            break;
         default:
-            kWarning() << "createNewUMLObject error unknown type: " << type << endl;
+            uWarning() << "createNewUMLObject error unknown type: " << type;
             return NULL;
     }
     o->setUMLPackage(parentPkg);
-    UMLDoc *doc = UMLApp::app()->getDocument();
-    parentPkg->addObject(o);
-    doc->signalUMLObjectCreated(o);
-    kapp->processEvents();
+
+    // will be caled in cmdCreateUMLObject
+    //parentPkg->addObject(o);
+
+    UMLApp::app()->executeCommand(new Uml::CmdCreateUMLObject(o));
+    qApp->processEvents();
     return o;
 }
 
 UMLObject* createUMLObject(Uml::Object_Type type, const QString &n,
                            UMLPackage *parentPkg /* = NULL */,
-                           bool solicitNewName /* = true */) {
+                           bool solicitNewName /* = true */)
+{
     UMLDoc *doc = UMLApp::app()->getDocument();
     if (parentPkg == NULL) {
         if (type == Uml::ot_Datatype) {
             parentPkg = doc->getDatatypeFolder();
         } else {
             Uml::Model_Type mt = Model_Utils::convert_OT_MT(type);
-            kDebug() << "Object_Factory::createUMLObject(" << n << "): "
-                << "parentPkg is not set, assuming Model_Type " << mt << endl;
+            uDebug() << "Object_Factory::createUMLObject(" << n << "): "
+                << "parentPkg is not set, assuming Model_Type " << mt;
             parentPkg = doc->getRootFolder(mt);
         }
     }
@@ -150,7 +164,7 @@ UMLObject* createUMLObject(Uml::Object_Type type, const QString &n,
     QString name = Model_Utils::uniqObjectName(type, parentPkg, n);
     bool bValidNameEntered = false;
     do {
-        name = KInputDialog::getText(i18n("Name"), i18n("Enter name:"), name, &ok, (QWidget*)UMLApp::app());
+        name = KInputDialog::getText(i18nc("UMLObject name", "Name"), i18n("Enter name:"), name, &ok, (QWidget*)UMLApp::app());
         if (!ok) {
             return 0;
         }
@@ -176,7 +190,8 @@ UMLObject* createUMLObject(Uml::Object_Type type, const QString &n,
     return o;
 }
 
-UMLAttribute *createAttribute(UMLObject *parent, const QString& name, UMLObject *type) {
+UMLAttribute *createAttribute(UMLObject *parent, const QString& name, UMLObject *type)
+{
     UMLAttribute *attr = new UMLAttribute(parent);
     attr->setName(name);
     attr->setType(type);
@@ -185,21 +200,29 @@ UMLAttribute *createAttribute(UMLObject *parent, const QString& name, UMLObject
     return attr;
 }
 
-UMLOperation *createOperation(UMLClassifier *parent, const QString& name) {
+UMLOperation *createOperation(UMLClassifier *parent, const QString& name)
+{
     UMLOperation *op = new UMLOperation(parent, name, g_predefinedId);
     return op;
 }
 
-UMLClassifierListItem* createChildObject(UMLClassifier* parent, Uml::Object_Type type) {
+UMLClassifierListItem* createChildObject(UMLClassifier* parent, Uml::Object_Type type)
+{
     UMLObject* returnObject = NULL;
     switch (type) {
-    case Uml::ot_Attribute:
-    case Uml::ot_EntityAttribute: {
-            UMLClassifier *c = dynamic_cast<UMLClassifier*>(parent);
+    case Uml::ot_Attribute: {
+        UMLClassifier *c = dynamic_cast<UMLClassifier*>(parent);
             if (c && !c->isInterface())
                 returnObject = c->createAttribute();
             break;
         }
+    case Uml::ot_EntityAttribute: {
+         UMLEntity *e = dynamic_cast<UMLEntity*>( parent );
+         if ( e ) {
+             returnObject = e->createAttribute();
+         }
+         break;
+        }
     case Uml::ot_Operation: {
             UMLClassifier *c = dynamic_cast<UMLClassifier*>(parent);
             if (c)
@@ -219,14 +242,36 @@ UMLClassifierListItem* createChildObject(UMLClassifier* parent, Uml::Object_Type
             }
             break;
         }
+    case Uml::ot_UniqueConstraint: {
+            UMLEntity* umlentity = dynamic_cast<UMLEntity*>( parent );
+            if ( umlentity ) {
+                returnObject = umlentity->createUniqueConstraint();
+            }
+            break;
+        }
+    case Uml::ot_ForeignKeyConstraint: {
+            UMLEntity* umlentity = dynamic_cast<UMLEntity*>( parent );
+            if ( umlentity ) {
+                returnObject = umlentity->createForeignKeyConstraint();
+            }
+            break;
+        }
+    case Uml::ot_CheckConstraint: {
+            UMLEntity* umlentity = dynamic_cast<UMLEntity*>( parent );
+            if ( umlentity ) {
+                returnObject = umlentity->createCheckConstraint();
+            }
+            break;
+        }
     default:
-        kDebug() << "ERROR UMLDoc::createChildObject type:" << type << endl;
+        uDebug() << "ERROR UMLDoc::createChildObject type:" << type;
     }
     return static_cast<UMLClassifierListItem*>(returnObject);
 }
 
 UMLObject* makeObjectFromXMI(const QString& xmiTag,
-                             const QString& stereoID /* = QString::null */) {
+                             const QString& stereoID /* = QString() */)
+{
     UMLObject* pObject = 0;
     if (Uml::tagEq(xmiTag, "UseCase")) {
         pObject = new UMLUseCase();
@@ -263,6 +308,8 @@ UMLObject* makeObjectFromXMI(const QString& xmiTag,
         pObject = new UMLEnum();
     } else if (Uml::tagEq(xmiTag, "Entity")) {
         pObject = new UMLEntity();
+    } else if (Uml::tagEq(xmiTag, "Category")) {
+        pObject = new UMLCategory();
     } else if (Uml::tagEq(xmiTag, "Stereotype")) {
         pObject = new UMLStereotype();
     } else if (Uml::tagEq(xmiTag, "Association") ||
@@ -275,7 +322,12 @@ UMLObject* makeObjectFromXMI(const QString& xmiTag,
         pObject = new UMLAssociation(Uml::at_Realization);
     } else if (Uml::tagEq(xmiTag, "Dependency")) {
         pObject = new UMLAssociation(Uml::at_Dependency);
+    } else if (Uml::tagEq(xmiTag, "Child2Category")) {
+        pObject = new UMLAssociation(Uml::at_Child2Category);
+    } else if (Uml::tagEq(xmiTag, "Category2Parent")) {
+        pObject = new UMLAssociation(Uml::at_Category2Parent);
     }
+
     return pObject;
 }
 
